Data access API

Use the data access API for a process to query job and machine data from
the resource manager and provide the functions to traverse the job and
machine objects and fetch the values for specific attributes.

You can use this API to query LoadLeveler resource manager daemons for
information about:


*  JOBS (job information)
*  MACHINES (machine information)
*  WLMSTAT (AIX Workload Manager)


This API can also be used to query a LoadLeveler history file for
accounting information about JOBS.


The data access API consists of the following subroutines: 

*  llr_get_data subroutine
*  llr_query_free_data subroutine
*  llr_query_get_data subroutine
*  llr_query_set subroutine


Using the data access API

The data access API makes use of a query object to facilitate each
request for LoadLeveler data.


The query object is used to specify the details of a query request. It
is initialized by the llr_query_set subroutine to specify the kind of
LoadLeveler objects requested and to specify filtering of those objects.
It is then passed to the llr_query_get_data subroutine to retrieve the
requested data.

To use this API, you need to call the subroutines in the following
order:

 
*  Call llr_init_resmgr, which must be called before using any of the
   data access APIs, to obtain the pointer to an opaque structure
   (llr_resmgr_handle_t). See the llr_init_resmgr subroutine for
   more information.

*  Call llr_query_set to specify the type of query and to filter the
   objects you want to query. See the llr_query_set subroutine for
   more information.

*  Call llr_query_get_data to send a query request to the specified
   daemon. See the llr_query_get_data subroutine for more
   information.

*  Call llr_get_data to access the data in the objects returned in
   llr_query_get_data. See the llr_get_data subroutine for more
   information.



llr_get_data subroutine

Use the llr_get_data subroutine to get data from llr_element_t
subroutine.


Library

LoadLeveler API library libllrapi.a (AIX) or libllrapi.so (Linux)


Syntax

int llr_get_data (llr_resmgr_handle_t *rm_handle, llr_element_t *element, 
                  llr_data_specification specification, void *resulting_data, 
                  llr_element_t **errObj);

Parameters

rm_handle
   Is the pointer to an opaque structure that is returned from the
   llr_init_resmgr subroutine.

element
   Is a pointer to the llr_element_t returned by the llr_query
   subroutine.

specification
   Is an enum specifying the data field within the data object to be
   read.

resulting_data
   Is a pointer to the location where the data is stored. If the call
   returns a nonzero value, an error has occurred and the contents of
   the location are undefined.

errorObj
   Is the address of a pointer to a LoadLeveler error object. The
   pointer to the error object should be set to NULL before calling this
   function. If this function fails, the pointer will point to an error
   object. The error messages stored in the error object can be
   displayed using the llr_error subroutine. The caller should use the
   llr_error subroutine to free the error object storage before reusing
   the pointer.


Description

Note: Before you use this subroutine, make sure you are familiar with
the concepts discussed in the topic, "Understanding the Job object model"
in the TWS LoadLeveler: Resource Manager.

object and specification are the input fields, while resulting_data is
an output field.

The llr_get_data subroutine of the data access API allows you to access
LoadLeveler objects. The parameters of llr_get_data are a LoadLeveler
object (LLR_element), a specification that indicates what information
about the object is being requested, and a pointer to the area where the
information being requested should be stored.

If the specification indicates an attribute of the element that is
passed in, the result pointer must be the address of a variable of the
appropriate type, and must be initialized to NULL. The type returned by
each specification is found in the specification tables. If the
specification queries the connection to another object, the returned
value is of type LLR_element. You can use a subsequent llr_get_data call
to query information about the new object.

The data type char* and any arrays of type int or char must be freed by
the caller.

LLR_element pointers cannot be freed by the caller.

For the specifications, LLR_MachineOperatingSystem and
LLR_MachineArchitecture, resulting_data_type returns the string "???" if
a query is made before the associated records are updated with their
actual values by the appropriate startd daemons.


Return Values

LLR_API_OK
         The data was successfully read from the object.

LLR_API_ERROR
         The data could not be read. A description of the error is
         provided in the errObj parameter.


Related Information

Subroutines: llr_query_free_data, llr_query_get_data, llr_query_set


The following table provides information on which daemons respond 
to which query_flags: 

query_flags summary
+------------------+-----------------------+--------------------------+
| When query type  | Filter_type (in       | Responded to by these    |
| (llr_query_type) | llr_query_filter_type | daemons (in              |
| is:              | ) can be:             | llr_query_source):       |
+------------------+-----------------------+--------------------------+
| LLR_JOBS_QUERY   | LLR_QUERY_ENDDATE     | LLR_QUERY_HISTORY_FILE   |
|                  |-----------------------|--------------------------|
|                  | LLR_QUERY_GROUP       | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER                       |
|                  |-----------------------|--------------------------|
|                  | LLR_QUERY_HOST        | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER                       |
|                  |-----------------------|--------------------------|
|                  | LLR_QUERY_JOBID       | LLR_QUERY_JOBMGR,        |
|                  |                       | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER                       |
|                  |-----------------------|--------------------------|
|                  | LLR_QUERY_STARTDATE   | LLR_QUERY_HISTORY_FILE   |
|                  |-----------------------|--------------------------|
|                  | LLR_QUERY_STEPID      | LLR_QUERY_JOBMGR,        |
|                  |                       | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER, LLR_QUERY_STARTD     |
|                  |-----------------------|--------------------------|
|                  | LLR_QUERY_USER        | LLR_QUERY_JOBMGR,        |
|                  |                       | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER                       |
|                  |-----------------------|--------------------------|
|                  | NULL                  | LLR_QUERY_HISTORY_FILE,  |
|                  |                       | LLR_QUERY_JOBMGR,        |
|                  |                       | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER, LLR_QUERY_STARTER    |
+------------------+-----------------------+--------------------------+
| LLR_MACHINES_QUE | LLR_QUERY_HOST        | LLR_QUERY_RESOURCE_MANAG |
| RY               |                       | ER                       |
|                  |-----------------------|--------------------------|
|                  | NULL                  | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER                       |
+------------------+-----------------------+--------------------------+
| LLR_WLMSTAT_QUER | LLR_QUERY_STEPID      | LLR_QUERY_RESOURCE_MANAG |
| Y                |                       | ER                       |
|                  |-----------------------|--------------------------|
|                  | NULL                  | LLR_QUERY_RESOURCE_MANAG |
|                  |                       | ER                       |
+------------------+-----------------------+--------------------------+



llr_query_free_data subroutine

Use the llr_query_free_data subroutine to free the query handle and all
of the query data associated with the specified query handle. All of the
llr_element_t objects in the object list that were obtained by the
llr_query_get_data subroutine will be freed.


Library

LoadLeveler API library libllrapi.a (AIX) or libllrapi.so (Linux)


Syntax

int llr_query_free_data (llr_resmgr_handle_t *rm_handle, 
                         llr_query_handle_t **q_handle, llr_element_t **errObj)


Parameters

rm_handle
   Is the pointer to an opaque structure that is returned from the
   llr_init_resmgr subroutine.

q_handle
   Is the address of the pointer to the opaque structure returned from
   the llr_init_resmgr subroutine. The memory associated with the
   structure will be freed and the pointer set to NULL.

errObj
   Is the address of a pointer to a LoadLeveler error object. The
   pointer to the error object should be set to NULL before calling this
   function. If this function fails, the pointer will point to an error
   object. The error messages stored in the error object can be
   displayed using the llr_error subroutine. The caller should use the
   llr_error subroutine to free the error object storage before reusing
   the pointer.


Description

rm_handle and q_handle are the input fields for this subroutine.

The query handle pointed to by q_handle is freed and all of the query
data associated with the specified query handle is freed. The q_handle
pointer is set to NULL.


Return Values

LLR_API_OK
         The llr_element_t objects were successfully freed.

LLR_API_ERROR
         The query element was not freed. A description of the error is
         provided in the errObj parameter.


Related Information

Subroutines: llr_get_data, llr_query_get_data, llr_query_set


llr_query_get_data subroutine

Use the llr_query_get_data subroutine to send a query request to the
specified daemon along with the request data specified by the
llr_query_set subroutine. The function will return a NULL-terminated
array of objects that match the request.


Library

LoadLeveler API library libllrapi.a (AIX) or libllrapi.so (Linux)


Syntax

 
int llr_query_get_data (llr_resmgr_handle_t *rm_handle, 
                        llr_query_handle_t *q_handle, 
                        llr_query_source_t query_daemon, const char *hostname, 
                        llr_element_t ***object_list, 
                        llr_element_t **errObj)


Parameters

rm_handle
   Is the pointer to an opaque structure that is returned from the
   llr_init_resmgr subroutine.

q_handle
   Is the pointer to an opaque structure that is returned from the
   llr_query_set subroutine.

query_daemon
   Is an enum specifying the LoadLeveler resource manager daemon or
   history file to query or whether you want to query job information
   stored in a history file. Possible values are: 

   *  LLR_QUERY_HISTORY_FILE
   *  LLR_QUERY_JOBMGR
   *  LLR_QUERY_MASTER
   *  LLR_QUERY_RESOURCE_MANAGER
   *  LLR_QUERY_STARTD
   *  LLR_QUERY_STARTER

hostname
   When the query_daemon parameter is set to LLR_QUERY_RESOURCE_MANAGER,
   the hostname parameter is ignored. When the query_daemon parameter is
   set to LLR_QUERY_HISTORY_FILE, the hostname parameter must be a
   pointer to a character string containing the name of the history file
   to query. For all other values of the query_daemon, the hostname
   parameter must be a pointer to a character string containing the host
   name of the daemon to query or NULL if the daemon on the local
   machine is to be queried.

object_list
   Is the address of a pointer to a NULL-terminated array of pointers to
   the requested objects. The object list is returned as output from
   this function.

errObj
   Is the address of a pointer to a LoadLeveler error object. The
   pointer to the error object should be set to NULL before calling this
   function. If this function fails, the pointer will point to an error
   object. The error messages stored in the error object can be
   displayed using the llr_error subroutine. The caller should use the
   llr_error subroutine to free the error object storage before reusing
   the pointer.


Description

rm_handle, q_handle, query_daemon, and hostname are the input fields for
this subroutine.

The output for this subroutine is returned in the object_list field. The
field will contain a NULL-terminated array of llr_element_t objects.
Each LoadLeveler daemon returns only the objects that it knows about.
Use the llr_get_data subroutine to extract data from the objects.


Return Values

LLR_API_OK
         The query request was successful.

LLR_API_COMM_ERROR
         The query request failed because of a communication error with
         a resource manager daemon. A description of the error is
         provided in the errObj parameter. The function can be retried
         when this error occurs.

LLR_API_ERROR
         The query request failed. A description of the error is
         provided in the errObj parameter.


Related Information

Subroutines: llr_get_data, llr_query_free_data, llr_query_set



llr_query_set subroutine

Use the llr_query_set subroutine to specify the type of query and the
data that is to be requested with a subsequent call to the
llr_query_get_data function. Queries can be filtered based on the
query_type and object_filter selected.


Library

LoadLeveler API library libllrapi.a (AIX) or libllrapi.so (Linux)


Syntax
int llr_query_set (llr_resmgr_handle_t *rm_handle, 
                   llr_query_handle_t **q_handle, llr_query_type_t query_type,
                   int filter_count, llr_query_filter_t *query_filter,
                   llr_element_t **errObj)

Parameters

rm_handle
   Is the pointer to an opaque structure that is returned from the
   llr_init_resmgr subroutine.

q_handle
   Is the address of a pointer to an opaque structure that is set if the
   query initialization is successful. The q_handle structure is
   returned as output from this function and is passed as a parameter to
   other query API functions

query_type
   Is an enum specifying the type of query. Possible values are: 

   *  LLR_JOBS_QUERY - query job information
   *  LLR_MACHINES_QUERY - query machine information
   *  LLR_WLMSTAT_QUERY - query AIX Workload Manager

filter_count
   Is an integer indicating the number of llr_query_filter_t structures
   in the query_filter array.

query_filter
   Is an array of llr_query_filter structures. The following table provides
   information on query_type (in llr_query_type_t) and related
   query_filter: 

query_filter summary
+-------------------+------------------------+------------------------+
| When query_type   | query_filter can be:   | Filter description:    |
| (in               |                        |                        |
| llr_query_type_t) |                        |                        |
| is:               |                        |                        |
+-------------------+------------------------+------------------------+
| LLR_JOBS_QUERY    | LLR_QUERY_ENDDATE      | Query by job end       |
|                   |                        | dates. History file    |
|                   |                        | query only.            |
|                   |------------------------|------------------------|
|                   | LLR_QUERY_GROUP        | Query by LoadLeveler   |
|                   |                        | group.                 |
|                   |------------------------|------------------------|
|                   | LLR_QUERY_HOST         | Query by job manager.  |
|                   |------------------------|------------------------|
|                   | LLR_QUERY_JOBID        | Query by resource      |
|                   |                        | manager job ID.        |
|                   |------------------------|------------------------|
|                   | LLR_QUERY_STARTDATE    | Query by job start     |
|                   |                        | dates. History file    |
|                   |                        | query only.            |
|                   |------------------------|------------------------|
|                   | LLR_QUERY_STEPID       | Query by resource      |
|                   |                        | manager job step ID.   |
|                   |------------------------|------------------------|
|                   | LLR_QUERY_USER         | Query by user ID.      |
+-------------------+------------------------+------------------------+
| LLR_MACHINES_QUER | LLR_QUERY_HOST         | Query by machine       |
| Y                 |                        | names.                 |
+-------------------+------------------------+------------------------+
| LLR_WLMSTAT_QUERY | LLR_QUERY_STEPID       | Query by resource      |
|                   |                        | manager job step ID.   |
+-------------------+------------------------+------------------------+

filter_data
   Is a NULL-terminated array of strings to be used to filter the data
   to be queried. The type of filter data is related to the specified
   filter_type as shown in the following table: 

filter_data value related to the query_filter value
+--------------------------------+------------------------------------+
| If you specify:                | Note:                              |
+--------------------------------+------------------------------------+
| LLR_QUERY_GROUP                | The filter_data contains a list of |
|                                | LoadLeveler group names.           |
+--------------------------------+------------------------------------+
| LLR_QUERY_HOST                 | The filter_data contains a list of |
|                                | LoadLeveler machine names.         |
+--------------------------------+------------------------------------+
| LLR_QUERY_JOBID                | The filter_data contains a list of |
|                                | job IDs.                           |
+--------------------------------+------------------------------------+
| LLR_QUERY_STARTDATE or         | The filter_data contains a list of |
| LLR_QUERY_ENDDATE              | two start dates or two end dates   |
|                                | having the format MM/DD/YYYY.      |
+--------------------------------+------------------------------------+
| LLR_QUERY_STEPID               | The filter_data contains a list of |
|                                | step IDs.                          |
+--------------------------------+------------------------------------+
| LLR_QUERY_USER                 | The filter_data contains a list of |
|                                | user IDs.                          |
+--------------------------------+------------------------------------+

errObj
   Is the address of a pointer to a LoadLeveler error object. The
   pointer to the error object should be set to NULL before calling this
   function. If this function fails, the pointer will point to an error
   object. The error messages stored in the error object can be
   displayed using the llr_error subroutine. The caller should use the
   llr_error subroutine to free the error object storage before reusing
   the pointer.


Description

rm_handle, q_handle, query_type, filter_count, and query_filter are the
input fields for this subroutine.

You can request certain combinations of object filters by calling
llr_query_set with an array of llr_query_filter_t structures. When you
do this, the query filter types you specify are or-ed together. The
following are valid combinations of object filters: 

*  LLR_QUERY_JOBID and LLR_QUERY_STEPID: the result is the union of both
   queries and any other query filter types (such as, LLR_QUERY_HOST)
   will be ignored

*  LLR_QUERY_STARTDATE and LLR_QUERY_ENDDATE: the result is the
   intersection of both queries

*  LLR_QUERY_HOST, LLR_QUERY_USER, and LLR_QUERY_GROUP: the result is
   the intersections of all of the queries

To query jobs owned by certain users and on specific machines, issue
llr_query_set with an array of llr_query_filter_t structures where the
first element contains LLR_QUERY_USER with the appropriate user IDs and
the second element contains LLR_QUERY_HOST with the appropriate host
names.

For example, suppose you issue llr_query_set with an array of two
llr_query_filter_t  structures where the first element contains a user
ID list of anton and meg, and the second element contains a host list of
k10n10 and k10n11. The objects returned are all of the jobs on k10n10
and k10n11 that belong to anton or meg.

Note that if you use two llr_query_filter_t structures with the same
flag, the second element will replace the first element. For history
file queries, llr_query_filter_type is restricted to LLR_QUERY_STARTDATE
and LLR_QUERY_ENDDATE.


Return Values

LLR_API_OK
         Indicates that the request was successfully set.

LLR_API_ERROR
         Indicates that the query request failed. A description of the
         error is provided in the errObj parameter.


Related Information

Subroutines: llr_get_data, llr_query_free_data, llr_query_get_data
