llrconfig - Manage the LoadLeveler configuration

Use the llrconfig command to manage LoadLeveler's configuration
database.


Syntax
 

llrconfig
         -? | -H | -v | -i [-q] [-f config_file_list] [-t
         cluster_configuration_file] |
         [-h hostlist] { -d keywords ... | -c keyword=value ... }


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-i 
   Initializes the configuration database using default LoadLeveler
   configuration files or the LoadLeveler configuration files specified
   by the -f flag. This flag can be used with the -f or -t flag.

-q 
   Specifies no prompting with the -i option.

-f config_file_list
   Is a blank-delimited list of full path names of configuration files
   that are used to initialize the database. You can only specify the -f
   flag if you are using the -i flag. You can specify more than one file
   to use for initializing the database; however, if a keyword is
   specified in more than one file, the last value is used.
   Administration files cannot be specified in the list.

-t cluster_configuration_file
   Specifies the full path name of an xCAT cluster configuration file
   used to supply LoadLeveler cluster information to initialize the
   database. This flag can only be used with the -i flag.

-h hostlist
   Is a blank-delimited list of machines. You can only specify the -h
   flag if you are using the -c and -d flags to change or display the
   keywords of these machines.

-d keywords ...
   Displays the values of the keywords in a blank-delimited list for the
   global or default machine, or for machines specified with the -h
   flag. If the value of a keyword cannot be displayed, an error message
   will be printed and the command continues to display the value of the
   next keyword. keywords are any configuration keywords relating to
   machines. Keywords related to user, group, class, machine_group, and
   cluster cannot be displayed using this command.

-c keyword=value ...
   Changes a keyword value to the new value provided. One or more
   strings in a format similar to keyword=value must be specified with
   the -c flag. The change applies to machines specified by the -h flag.
   If a machine is not specified, the change applies to the global or
   default machine. 

   keyword=value is any configuration keyword relating to machines.
   Keyword values related to user, group, class, machine_group, and
   cluster cannot be changed using this command.


Description

The llrconfig command is used to manage LoadLeveler's configuration
database. You can only specify one -i, -c, or -d flag at a time.

To initialize the database configuration of LoadLeveler, llrconfig -i
provides several ways to put the LoadLeveler configuration and
administration information into the database.

The following table lists some of your configuration and database information
options: 

LoadLeveler configuration and database information options
+-----------------------+----------------------+----------------------+
| Initialize command    | When to use:         | Which files are      |
| option:               |                      | used:                |
+-----------------------+----------------------+----------------------+
| llrconfig -i          | If LoadLeveler is    | The first            |
|                       | already configured   | configuration file   |
|                       | using a file-based   | found by searching   |
|                       | configuration        | in these locations:  |
|                       |                      |  * The configuration |
|                       |                      | file pointed to by   |
|                       |                      | the LoadLConfig      |
|                       |                      | keyword in the       |
|                       |                      | /etc/LoadL.cfg       |
|                       |                      | master configuration |
|                       |                      | file                 |
|                       |                      |  * A default         |
|                       |                      | configuration file,  |
|                       |                      | LoadL_config, found  |
|                       |                      | in the home          |
|                       |                      | directory of the     |
|                       |                      | LoadLeveler user ID  |
|                       |                      |  * The sample        |
|                       |                      | configuration file   |
|                       |                      | LoadL_config.l from  |
|                       |                      | the samples          |
|                       |                      | directory            |
+-----------------------+----------------------+----------------------+
| llrconfig -i -f       | If you want to use   | The specified files  |
| config_file_list      | one or more          | are used, in the     |
|                       | configuration files  | order that they were |
|                       | to load the database | specified.           |
+-----------------------+----------------------+----------------------+
| llrconfig -i -t       | If you have set up a | Any files specified  |
| cluster_configuration | cluster              | by the -f option     |
| _file -f              | configuration file   | followed by the      |
| config_file_list      | for use with xCAT    | LoadLeveler section  |
|                       |                      | of the file          |
|                       |                      | specified by the -t  |
|                       |                      | option.              |
+-----------------------+----------------------+----------------------+

You can use the -f option to list one or more configuration files. If
duplicate keywords are specified in the configuration files, the value
of the last keyword will be used. If a LoadL_config.local file is
specified in the list, the keywords found in that file will be set for
the default or global configuration, rather than for any specific
machine. To specify machine-specific information, you need to set those
keywords in the machine or machine_group stanzas in the administration
file associated with the configuration file used to load the
configuration database, or update the configuration database for
specific machines after the initialize command has run. You cannot
specify an administration file in the list of configuration files.
However, you can supply an administration file to use for initializing
the database by assigning it to the ADMIN_FILE keyword in a
configuration file that is in the list.

When llrconfig -i is run, for any value that the user specifies that is
the same as the LoadLeveler code default value, no value will be set in
the configuration database.

It is suggested you do not run the initialization more than once. If you
run the initialize option again after the database has been initialized,
the database will be initialized again from the configuration files and
any updates that were made to the database configuration will be lost.

The initialize option must be run by the root user. It must be run on a
node where the database or database client is installed.

To update the database after initialization, you can issue the llrconfig
-c command on any LoadLeveler node that has been set up to access the
database using unixODBC. To specify machine-specific information, use
the -h flag to specify one or more machines. Changes made without the -h
flag apply to the default or global machine.

It is not necessary to reconfigure LoadLeveler to pick up changes made
using the llrconfig -c command. A reconfiguration will be propagated to
the nodes needing reconfiguration.

When several keyword changes are specified on the command line, if the
value of a keyword cannot be changed, an error message will be printed
and the command will continue to change the value of the next keyword.

To remove the setting of a keyword, set it using the format -c keyword=
or -c keyword="". If set without a value, the keyword's value will be
removed.

If keyword="value" is specified with the -c flag, the quotes will not be
part of the assigned value. You must use quotes whenever the value
includes shell special characters. For example, llrconfig -c start = 4 >
5 is not correct and should be written as llrconfig -c start = "4 > 5".


Examples

1. To migrate your existing file-based configuration to the
   configuration database, issue: 
   llrconfig -i

2. To initialize a configuration using a cluster configuration file and
   one of the provided sample files, issue: 
   llrconfig -i -t /tmp/topo -f \ 
   /usr/lpp/LoadL/resmgr/full/samples/LoadL_config.l

    
   where /tmp/topo contains:
  

   # LoadLeveler cluster manager daemons and administrator
   ll-config:
        central_manager_list = hmc01 hmc02 hmc03
        resource_mgr_list = hmc01 hmc02 hmc03
        loadl_admin = loadl root loadladmin
        schedd_list = bbxn01 bbxn02 bbyn01 bbyn02

3. To initialize a configuration with keywords from the specified files,
   issue: 
   llrconfig -i -f /usr/lpp/LoadL/resmgr/full/samples/LoadL_config \ 
   /usr/lpp/LoadL/resmgr/full/samples/LoadL_config.local
  

   Note: The local file keywords are applied to the global or default
   machine rather than a particular machine.

4. To show the value of the polling_frequency, issue: 
   llrconfig -d polling_frequency

5. To change the configured default polling_frequency to 120, issue: 
   llrconfig -c polling_frequency = 120

6. To set debug flags for the Schedd daemon on c197blade3b01, issue: 
   llrconfig -h c197blade3b01 -c SCHEDD_DEBUG=D_FULLDEBUG

7. To reset debug flags to use the default value for the Schedd daemon
   on c197blade3b01, issue: 
   llrconfig -h c197blade3b01 -c SCHEDD_DEBUG=

    
   or
   

   llrconfig -h c197blade3b01 -c SCHEDD_DEBUG=""

8. To change class initiators on machine c94n01, issue: 
   llrconfig -h c94n01 -c class="small(4) large(3)" max_starters = 6 

9. To change schedd_debug to "D_ALWAYS D_FULLDEBUG D_SCHEDD", and
   master_debug to "D_ALWAYS D_FULLDEBUG" for machine c94n01, issue: 
   llrconfig -h c94n01 -c schedd_debug = D_ALWAYS D_FULLDEBUG D_SCHEDD \ 
   master_debug = D_ALWAYS D_FULLDEBUG 


Results

*  When no errors are found:

   [c197blade8b14][/]> llrconfig -i
   LoadLeveler tables are being created in the xcatdb database.
   Initializing configuration data in the LoadLeveler tables from the 
   following file or files:
   
   /u/loadl/LoadL_config.c197blade8b14
   
   Continue? (y/n): y
   llrconfig: The database initialization has completed. 

*  When information messages or errors are found during configuration
   check, and the configuration database is still initialized: 

   [c197blade8b14][/]> llrconfig -i
   LoadLeveler tables are being created in the xcatdb database.
   Initializing configuration data in the LoadLeveler tables from the
   following file or files:
   /u/loadl/LoadL_config
   Continue? (y/n): y
   negotiator_debug: The value, d_loadl, is not valid.
   starter_debug: The keyword is specified in the configuration but has no 
   value set.
   trunc_gsmonitor_log_on_open: The keyword is no longer supported.
   releasedir: can't read "/opt/ibmll/LoadL/fulla".
   bin: can't read "$(RELEASEDIR)/bin".
   lib: The keyword is no longer supported.
   acct_validation: can't execute "$(BIN)/llacctval".
   kbdd: can't execute "$(BIN)/LoadL_kbdd".
   startd: can't execute "$(BIN)/LoadL_startd".
   process_tracking_extension: can't read "$(BIN)".
   region_mgr: can't execute "$(BIN)/LoadL_region_mgr".
   resource_mgr: can't execute "$(BIN)/LoadL_resource_mgr".
   schedd: can't execute "$(BIN)/LoadL_schedd".
   negotiator: can't execute "$(BIN)/LoadL_negotiator".
   starter: can't execute "$(BIN)/LoadL_starter".
   master: can't execute "$(BIN)/LoadL_master".
   llrconfig: The database initialization has completed.



Security

Only the root user can issue this command with the -i flag on a node
running the database software.

LoadLeveler administrators must login to a node with database access
through unixODBC and have a ~/.odbc.ini file set up providing permission
to issue this command with the -c or -d flag.
