llrctl - Control resource manager daemons and machines

Use the llrctl command to control LoadLeveler resource manager daemons
on all members of the LoadLeveler cluster.


Syntax

llrctl { -? | -H | -v | [-q] [-g | -h hostlist] keyword }


Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-g 
   Indicates that the command applies globally to all machines that are
   listed in the administration file.

-h hostlist
   Indicates that the command applies to only the hostlist machine in
   the LoadLeveler cluster. If neither -h nor -g is specified, the
   default is the machine on which the llrctl command is issued.

keyword
   Must be specified after all flags and can be the following: 

   capture eventname
      Captures accounting data for all jobs running on the designated
      machines. eventname is a user-defined name associated with the
      data when you run this command. It must be a character string
      containing no blanks. The data is captured in the accounting
      records in the history file. For more information, see the
      discussion of collecting job resource data based on events in TWS
      LoadLeveler: Using and Administering.

   ckconfig
      Checks the defined configuration. ckconfig reads either the
      configuration database or the configuration files (including the
      global, local, and the administration files), and reports all
      error and informational messages. The errors and informational
      messages produced by ckconfig will be sent to standard error and
      will also be logged to the ckconfigLog file located in the
      directory specified in $LOG in the configuration file.

   drain [jobmgr]
      When you issue drain with no options or drain jobmgr, the
      following occurs: 

      *  The job manager accepts no more jobs for submission.

      *  Job steps in the Starting or Running state in the job manager
         queue are allowed to continue running.

      *  Job steps in the Idle state in the job manager queue are
         drained, meaning they will not get dispatched.

   dumplogs
      When the logging buffer is enabled, llrctl dumplogs will cause the
      log messages in the logging buffer to be written to the related
      log file.

   reconfig
      Forces all daemons to reread the administration and configuration
      files.

   recycle
      Stops all LoadLeveler resource manager daemons and restarts them.

   resume [jobmgr]
      When you issue resume with no options or resume jobmgr, the
      following occurs: 

      *  The job manager will accept jobs for submission.

      *  The steps in the Idle state in the job manager queue are no
         longer drained; they will be considered for dispatch.

   rmshm
      Allows root to remove all LoadLeveler shared memory segments and
      associated semaphores.

   start
      When you issue start, it starts the LoadLeveler resource manager
      daemons on the machine or machines designated, either explicitly
      or implicitly. When you issue start without the -g or -h flag, the
      LoadLeveler resource manager daemons are started on the same
      machine that issued the command.

   stop
      When you issue stop, it stops the LoadLeveler resource manager
      daemons on the machine or machines designated, either explicitly
      or implicitly. When you issue stop without the -g or -h flag, the
      LoadLeveler resource manager daemons are stopped on the same
      machine that issued the command.

   version
      Displays release number, service level, service level date, and
      operating system information for every LoadLeveler executable.


Description

This command sends a message to the master daemon on the target machine
requesting that action be taken on the members of the LoadLeveler
cluster. Note the following when using this command: 

*  To perform the control operations of the llrctl command, you must be
   a LoadLeveler administrator. The only exceptions to this rule are the
   start and rmshm operations.

*  LoadLeveler will fail to start if any value has been set for the
   MALLOCTYPE environment variable.

*  For a file-based configuration, after you make changes to the
   administration and configuration files for a running cluster, be sure
   to issue llrctl reconfig. This command causes the LoadLeveler
   resource manager daemons to reread these files, and prevents problems
   that can occur when the LoadLeveler resource manager commands are
   using a new configuration while the daemons are using an old
   configuration. 

   For the database configuration option, you should reconfigure after
   you update the configuration database using the configuration editor.

*  If a job step is running on a machine that receives the llrctl
   recycle command, or the llrctl stop and llrctl start commands, the
   running job step is terminated. If the restart option in the job
   command file was set to yes, then the job step will be restarted when
   LoadLeveler is restarted. If the job step is checkpointable, it will
   be restarted from the last valid checkpoint file when LoadLeveler is
   restarted.

*  If you find that the llrctl -g command (even if it is specified with
   additional options) is taking a long time to complete, you should
   consider using the AIX command dsh to send llrctl commands (omitting
   the -g flag) to multiple nodes in a parallel fashion.


Examples

1. This example stops LoadLeveler on the machine named iron: 

   llrctl -h iron stop

2. This example starts the LoadLeveler resource manager daemons on all
   members of the LoadLeveler cluster, starting with the resource
   manager, as defined in the machine stanzas of the administration
   file: 

   llrctl -g start

3. This example causes the LoadLeveler resource manager daemons on
   machine iron to re-read the administration and configuration files,
   which may contain new configuration information for the iron machine:
   
   llrctl -h iron reconfig

4. This example illustrates how to capture accounting information on a
   work shift called day on the machine iron: 

   llrctl -h iron capture day
    

   You can capture accounting information on all the machines in the
   LoadLeveler cluster by using the -g option, or you can collect
   accounting information on the local machine by simply issuing the
   following: 

   llrctl capture day
  

   Capturing information on the local machine is the default. For more
   information, see the discussion of collecting job resource data based
   on events in TWS LoadLeveler: Using and Administering.


Security

LoadLeveler administrators can issue this command.

Only the root user can issue this command with the rmshm keyword.