
llrq - Query job information

Use the llrq command to query information about jobs in the resource
manager job database.

Syntax
 
llrq  [-?] [-H] [-v] [-W] [-l] [-w] [-j joblist | joblist] [-u userlist]
      [-h hostlist] [-f category_list] [-r category_list]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-l 
   Specifies that a long listing be generated for each job for which
   status is requested.

-w 
   Provides AIX Workload Manager (WLM) CPU, real memory, virtual memory,
   and large page statistics for jobs in the running state. This flag
   can be used with a joblist, steplist, or a single stepid. All other
   flags except -h will result in an error message.

-j joblist |joblist
   Is a blank-delimited list of resource manager job and step IDs. When
   a job identifier is specified, the command action is taken for all
   steps of the job. At least one job or step identifier must be
   specified.

-u userlist
   Is a blank-delimited list of users. Only job steps belonging to users
   in this list are queried.

-h hostlist
   Is a blank-delimited list of machines. Only job steps managed by the
   job manager on machines in this list are queried. When the -h flag is
   used with the -w flag, only a single machine name can be specified to
   obtain the WLM statistics for that machine.

-f category_list
   Is a blank-delimited list of categories to query. Each category
   specified must be preceded by a percent sign. The category_list
   cannot contain duplicate entries. This flag is used to create a
   customized version of the standard llrq listing. This flag cannot be
   used with the -l flag. The output fields produced by this flag all
   have a fixed length. The output is displayed in the order that the
   categories are specified. category_list can be one or more of the
   following: 

   %a       Account number
   %cc      Completion code
   %dc      Completion date
   %dd      Dispatch Date
   %dh      Hold date
   %dq      Queue date ("Submitted" date of "standard" llrq output)
   %gl      LoadLeveler group
   %gu      UNIX group
   %h       Host name (first host name if more than one machine is
            allocated to the job step)
   %id      Step ID
   %is      Virtual image size
   %jn      Job name
   %jt      Job type
   %nh      Number of hosts allocated to the job step
   %o       Job owner
   %sn      Step name
   %st      Status

-r category_list
   Is a blank-delimited list of categories to query. Each category you
   specify must be preceded by a percent sign. This flag cannot be uses
   with the -l flag. The output produced by this flag is considered raw,
   in that the fields can be variable in length. Output fields are
   separated by an exclamation point (!). category_list can be one or
   more of the formats listed under the -f flag.

Description

The llrq command queries information about jobs in the LoadLeveler
queues.

Note the following when using this command:

*  If a job step is not specified and if -u or -h is not specified, all
   jobs are queried.
*  If a job step is specified, you cannot specify -u or -h, except in
   the case of -w, for which the -h flag has special meaning.
*  When -u or -h are used in combination, the result is the intersection
   of the job steps selected by each flag.
*  The -r and -f flags are mutually exclusive. If specified together,
   the following error message is displayed:
   2512-038 The -r option and the -f option are not compatible.

Examples

1. This example generates the standard listing where the cluster has two
   jobs running and one job waiting: 

   Id                     Owner     Submitted   ST Class      Running On 
   ---------------------  --------- ----------- -- ---------  ----------
   mars12.304.0@mars12    rose      11/7  11:41 R  No_Class   mars09 
   mars11.26.0@mars11     bill      11/8  02:34 R  high       mars01 
   mars11.27.0@mars04     zach      11/8  07:12 I  low       
   
   3 job step(s) in queue, 1 waiting, 0 pending, 2 running, 0 held, 
   0 preempted
    
   The standard listing includes the following fields:
    
   Class    Job class.

   Id       The resource manager job step ID. Due to space limitations,
            the job step ID may be truncated. If the job step ID is
            truncated, a dash (-) will appear at the end to indicate
            that characters have been left out. To see the full resource
            manager job step ID, run llrq with the -l flag.

   Owner    User ID that the job will be run under.

   Running On
            If running, the name of the machine the job step is running
            on. This is blank when the job is not running. For a
            parallel job step, only the first machine is shown.

   ST       Current state of the job step. For more information, see the
            "LoadLeveler job states" topic in TWS LoadLeveler: Using and
            Administering.

   Submitted
            Date and time of job submission. 

2. This example generates the long listing. The long listing is
   generated when you specify the -l flag with the llrq command: 

   llrq -l
    
   The long listing includes the following fields. 
    
   Account  The account number specified in the job command file.

   Adapter Requirement
            Reflects the settings of the network keyword in the job
            command file. 

            For more information on the network keyword statement, see
            the "Job command file keyword descriptions" topic in TWS
            LoadLeveler: Using and Administering.

   Allocated Hosts
            The machines that have been allocated for this job step.

   Args     Arguments that were passed to the executable.

   Blocking Reflects the settings for the blocking keyword in the job
            command file.

   Bulk Transfer
            Indicates that the value will be Yes or No depending on
            whether the application requested that the communication
            subsystem use bulk transfer by specifying bulkxfer=yes in
            the job command file.

   Checkpoint Directory
            Value of the ckpt_dir keyword.

   Checkpoint SubDir
            Value of theckpt_subdir keyword.

   Checkpointable
            Indicates if LoadLeveler considers the job step
            checkpointable (yes, no, or interval).

   Ckpt Execute Dir
            The directory where the job step's executable will be saved
            for checkpointable jobs.

   Ckpt Hard Limit
            Checkpoint hard limit as specified at job step submission.

   Ckpt Soft Limit
            Checkpoint soft limit as specified at job step submission.

   Class    The class of the job step as specified at job submission.

   Cmd      The name of the executable associated with the executable
            keyword (if specified) or the name of the job command file.

   Comment  The comment specified by the comment keyword in the job
            command file.

   Completion Code
            The status returned by the wait3 UNIX system call.

   Completion Date
            Date and time job completed or exited.

   Core Hard Limit
            Core hard limit as specified at job submission.

   Core Soft Limit
            Core soft limit as specified at job submission.

   Coschedule
            Indicates whether the job step is required to be coscheduled
            (yes or no).

   Cpu Hard Limit
            CPU hard limit as specified at job submission.

   Cpu Soft Limit
            CPU soft limit as specified at job submission.

   Cpus Per Core
            The CPUs per processor core requested by the job.

   Data Hard Limit
            Data hard limit as specified at job submission.

   Data Soft Limit
            Data soft limit as specified at job submission.

   Data Staging Script
            The script that will be run for data staging in this job
            step.

   Data Stg Dependency
            An expression specifying how this step is dependent on other
            data staging steps in the job.

   Dependency
            Job step dependencies as specified at job submission.

   Dispatch Time
            The time that the job was dispatched.

   Env      Environment variables to be set before executable runs.
            Appears only when the -x option is specified.

   Err      The file to be used for stderr.

   Error Text
            The error text in the Blue Gene job record from the Blue
            Gene DB2 database. This field is displayed for Blue Gene
            jobs only.

   File Hard Limit
            File hard limits as specified at job submission.

   File Soft Limit
            File soft limit as specified at job submission.

   Hold Job Until
            Job step is deferred until this date and time.

   In       The file to be used for stdin.

   Initial Working Dir
            The directory from which the job step is run. The relative
            directory from which the stdio files are accessed, if
            appropriate.

   Job Accounting Key
            The Job Accounting Key is a unique identifier for a
            LoadLeveler job step. The accounting key is stored in the
            AIX accounting record for each process associated with a
            LoadLeveler job step. This field can be used to correlate
            AIX accounting records with LoadLeveler accounting records.
            The Job Accounting Key is stored in the history file and can
            be displayed using the llsummary -l command. 

            This keyword is not applicable on LoadLeveler for Linux
            platforms.
             
            For more information on the Job Accounting Key, see the
            "Correlating AIX and LoadLeveler accounting records" topic
            in TWS LoadLeveler: Using and Administering.

   Job Name The name of the job.

   Job Step ID
            The job step identifier.

   Large Page
            Indicates whether Large Page memory should be used to run
            this job step. Can be Y (use Large Page memory if
            available), N (No), or M (Mandatory).

   LoadLeveler Group
            The LoadLeveler group associated with the job step.

   Machine Speed
            For a serial job step, the value associated with the speed
            keyword of the machine that is running this job step. For a
            parallel job step, the value associated with the speed
            keyword of the first machine that has been allocated for
            this job step.

   Max Processors
            The maximum number of processors that can be used for this
            job step.

   McmAffinityOptions
            The MCM affinity options for the job.

   MetaCluster JobId
            The ID assigned by LoadLeveler to the job step for use in
            all MetaCluster operations on that job step. This ID
            corresponds to the MDCR_JOBID environment variable used by
            MetaCluster.

   Min Processors
            The minimum number of processors needed for this job step.

   Network Usage
             
            *  Network usages information has the format: 

               Network Usages: Network Usage, ... , Network Usage

            *  Network usage has the format: 

               Network Id (Instances, protocol, mode, \
	       Number of Windows, adapter window memory)
                
               where:
                
               Network Id = 0
                        Specifies that all switch networks are used.
               Network Id = -1
                        Specifies that the Ethernet network is used.
               Network Id > 0
                        Specifies the network ID that is used.

   (Node) Allocated Hosts
             
            *  The machines of this Node type that have been allocated
               for this job step. The format is: 
               hostname:task status: cpu usage, ... ,cpu usage + ... +

            *  The CPU usage information has one of the following
               formats: 
               				
               CPU <cpulist>; 
               MCMnumber:CPU <cpulist>;
                
               The cpulist is a blank-delimited list of individual CPU
               IDs or CPU ranges, or a combination of both CPU IDs and
               CPU ranges. The CPU range is specified as the starting
               CPU ID and the ending CPU ID separated by a hyphen (-).

   (Node) Name
            Blank value. Reserved for future use.

   (Node) Node actual
            Actual number of machines of this Node type that are used in
            the running of this job step.

   (Node) Node maximum
            Maximum number of machines of this Node type that can be
            used to run this job step.

   (Node) Node minimum
            Minimum number of machines of this Node type required to run
            this job step.

   (Node) Preferences
            Job step preferences as specified at job submission.

   (Node) Requirements
            Job step requirements as specified at job submission.

   (Node/Master Task) Exec Args
            The arguments passed to the master task executable.

   (Node/Master Task) Executable
            The executable associated with the master task.

   (Node/Master Task) Num Task Inst
            The number of task instances of the master task.

   (Node/Master Task) Task Instance
            Task instance information has the format: 
            hostname: task ID

   (Node/Task) Num Task Inst
            The number of task instances.

   (Node/Task) Task Instance
             
            *  Task instance information has the format: 
               hostname: task ID: cpu usage

            *  The CPU usage information has one of the following
               formats: 
               				
               CPU <cpulist>; 
               MCMnumber:CPU <cpulist>;
                
               The cpulist is a blank-delimited list of individual CPU
               IDs or CPU ranges, or a combination of both CPU IDs and
               CPU ranges. The CPU range is specified as the starting
               CPU ID and the ending CPU ID separated by a hyphen (-).

   Node Resources
            Reflects the settings for the node_resources keyword in the
            job command file.

   Node Usage
            A request that a node be shared or not shared or that a
            time-slice is not shared. The user specifies this request
            while submitting the job.

   Notifications
            The notification status for the job step, where: 

            always
               Indicates notification is sent through the mail for the
               complete, error, never, and start notification
               categories.

            complete
               Indicates notification is sent through the mail only when
               the job step completes.

            error
               Indicates notification is sent through the mail only when
               the job step terminates abnormally.

            never
               Indicates notification is never sent.

            start
               Indicates notification is sent through the mail only when
               starting or restarting the job step.

   Notify User
            The user to be notified by mail of a job's status.

   Out      The file to be used for stdout.

   Owner    The user ID that the job will be run under.

   parallel_threads
            Indicates whether the job requests thread binding and the
            number of parallel threads of an OpenMP job.

   Partition ID
            The ID of the Blue Gene partition allocated for the job.
            This field is displayed for Blue Gene jobs only.

   Partition State
            The state of the Blue Gene partition allocated for the job.
            This field is displayed for Blue Gene jobs only.

   Port Number
            The port number for InfiniBand resources used by the running
            job.

   Preempt Wait Count
            Specifies the number of job steps that an idle job step must
            preempt before it can be started.

   Preemptable
            Indicates whether a job step is preemptable (yes or no).

   Preferences
            Job step preferences as specified at job submission.

   Queue Date
            The date and time that LoadLeveler received the job.

   Requirements
            Job step requirements as specified at job submission.

   Resource The resource being enforced by WLM. This is either CPU, Real
            Memory, Virtual Memory, or Large Page Memory.

   Resources
            Reflects the settings for the resources keyword in the job
            command file.

   Restart  Restart status (yes or no).

   Restart From Ckpt
            Indicates if a job has been restarted from an existing
            checkpoint (yes or no).

   Restart Same Nodes
            Indicates if a job step should be restarted on the same
            nodes after vacate (yes or no).

   Rotate   Indicates whether the scheduler is free to rotate the
            requested Blue Gene partition shape in order to match an
            available partition (TRUE or FALSE). This field is displayed
            for Blue Gene jobs only.

   RSet     The RSet requirement of the job.

   Rss Hard Limit
            RSS hard limit as specified at job step submission.

   Rss Soft Limit
            RSS soft limit as specified at job step submission.

   Running Host
            For a serial job step, the machine that is running this job
            step. For a parallel job step, the first machine that has
            been allocated for this job step.

   Scheduler ID
            LoadLeveler scheduler ID.

   Sending Cluster
            The cluster name that the job was sent from when moved. This
            field only displays multicluster-specific information.

   Shape Allocated
            The allocated shape of the Blue Gene partition for the job.
            This field is defined only for running-like jobs. This field
            is displayed for Blue Gene jobs only.

   Shape Requested
            The requested shape of the Blue Gene partition for the job,
            if defined, in units of base partitions. This field is
            displayed for Blue Gene jobs only.

   Shell    The shell to be used when the job step runs.

   Size Allocated
            The size of the Blue Gene partition for the job in units of
            compute nodes. The size allocated is not always identical to
            the requested size. This field is displayed for Blue Gene
            jobs only.

   Size Requested
            The requested size of the Blue Gene partition for the job in
            units of compute nodes. The size must be equivalent to the
            size of the shape, if such is defined. This field is
            displayed for Blue Gene jobs only.

   SMT requested
            Indicates the required simultaneous multithreading (SMT)
            state, which is defined in the job command file, if the job
            step requires SMT to be turned on or off. Valid values are
            yes or no.

   SMT required
            Indicates the required simultaneous multithreading (SMT)
            state, if the job step requires SMT to be enabled, disabled,
            or kept as is. Valid values are yes, no, or as_is.

   Stack Hard Limit
            Stack hard limit as specified at job submission.

   Stack Soft Limit
            Stack soft limit as specified at job submission.

   Starter idrss/Step Starter idrss
            An integral value of the amount of unshared memory in the
            data segment of a process (expressed in units of kilobytes *
            seconds-of-execution).

   Starter inblock/Step inblock
            Number of times file system performed input. Cumulative
            total.

   Starter isrss/Step isrss
            Depending on the Operating System, this field may contain
            the integral value of unshared stack size.

   Starter ixrss/Step ixrss
            An integral value indicating the amount of memory used by
            the text segment that was also shared among other processes
            (expressed in units of kilobytes * seconds-of-execution).

   Starter majflt/Step majflt
            Number of page faults (I/O required). Cumulative total.

   Starter maxrss/Step maxrss
            Maximum resident set size utilized. Maximum value.

   Starter minflt/Step minflt
            Number of page faults (reclaimed). Cumulative total.

   Starter msgrcv/Step msgrcv
            Number of IPC messages received. Cumulative total.

   Starter msgsnd/Step msgsnd
            Number of IPC messages sent. Cumulative total.

   Starter nivcsw/Step nivcsw
            Number of involuntary context switches. Cumulative total.

   Starter nsignals/Step nsignals
            Number of signals delivered. Cumulative total.

   Starter nswap/Step nswap
            Number of times swapped out. Cumulative total.

   Starter nvcsw/Step nvcsw
            Number of context switches due to voluntarily giving up
            processor. Cumulative total.

   Starter oublock/Step oublock
            Number of times file system performed output. Cumulative
            total.

   Starter System Time/Step System Time
            CPU system time of Starter/Step processes. Cumulative total.

   Starter Total Time/Step Total Time 
            CPU total time of Starter/Step processes. Cumulative total.

   Starter User Time/Step User Time
            CPU user time of Starter/Step processes. Cumulative total.

   Status   The status (state) of the job. For more information, see the
            "LoadLeveler job states" topic in TWS LoadLeveler: Using and
            Administering.

   Step Adapter Memory
            The total adapter pinned memory for the job step.

   Step Cpu Hard Limit
            Job step CPU hard limit as specified at job submission.

   Step Cpu Soft Limit
            Job step CPU soft limit as specified at job submission.

   Step Cpus
            The total ConsumableCpus for the job step.

   Step Large Page Memory
            The total ConsumableLargePageMemory for the job step.

   Step Name
            The name of the job step.

   Step rCxt Blocks
            The number of rCxt blocks for switch adapters.

   Step Real Memory
            The total ConsumableMemory for the job step.

   Step Type
            Type of job step: 
            *  Serial
            *  General parallel
            *  Blue Gene
            *  MPICH parallel

   Step Virtual Memory
            The total ConsumableVirtualMemory for the job step.

   Structure Version
            An internal version identifier.

   Submitting Host
            The name of the machine to which the job is submitted.

   Task Affinity
            The task affinity requirements of the job.

   Task_geometry
            Reflects the settings for the task_geometry keyword in the
            job command file.

   total    Total CPU time consumed in milliseconds. CPU resource only.

   Unix Group
            The effective UNIX group name.

   User Space Windows
            The number of switch adapter windows assigned to the job
            step.

   Virtual Image Size
            The value of the image_size keyword (if specified) or the
            size of the executable associated with the executable
            keyword (if specified) or the size of the job command file.

   Wall Clk Hard Limit
            Wall clock hard limit as specified at job submission.

   Wall Clk Soft Limit
            Wall clock soft limit as specified at job submission.

   Wiring Allocated
            Allocated type of wiring for the Blue Gene partition. It is
            either TORUS or MESH. This field is displayed for Blue Gene
            jobs only.

   Wiring Requested
            Requested type of wiring for the Blue Gene partition. It is
            TORUS, MESH, or PREFER_TORUS. This field is displayed for
            Blue Gene jobs only.

3. Using the abbreviated form of jobid, this example generates a
   standard listing for all job steps with jobid 12 assigned by the
   local machine:
   
   llrq 12

4. This example generates a standard listing for all job steps owned by
   either rich or nathan and bound to reservation 6:
   
   llrq -u rich nathan -R 6

5. The following example generates a customized listing for all job
   steps: 
    
   llrq -f %id %o %R 

   You should receive a response similar to the following:
   
   Step Id                  Owner       Reservation ID          
   ------------------------ ----------- --------------------------
   c94n04.5.0               zhong       c94n04.2.r              
   c94n04.4.0               zhong                               
   
   2 job step(s) in queue, 1 waiting, 0 pending, 0 running, 1 held, 
                           0 preempted

6. This example generates a customized and formatted standard listing: 

   llrq -f %id %dq %dd %gl %h

   You should receive output similar to the following:     
  
   Step Id         Queue Date  Disp. Date  LL Group   Running On
   --------------  ----------- ----------- ---------- ---------------
   ll6.2.0         04/08 09:19 04/08 09:21 No_Group   ll6.pok.ibm.com
   ll6.1.0         04/08 09:19 04/08 09:21 No_Group   ll6.pok.ibm.com
   ll6.3.0         04/08 09:19 04/08 09:21 No_Group   ll5.pok.ibm.com
   
   3 job step(s) in queue, 0 waiting, 0 pending, 3 running, 0 held, 
   0 preempted

7. This example generates a customized, unformatted (raw) standard
   listing. Output fields are separated by an exclamation point (!). 
   
   llrq -r %id %dq %dd %gl %h

   You should receive output similar to the following: 
     
   ll6.pok.ibm.com.2.0!01/16/2009 09:19!01/16/2009 09:21! 
                       No_Group!ll6.pok.ibm.com
   ll6.pok.ibm.com.1.0!01/16/2009 09:19!01/16/2009 09:21! 
                       No_Group!ll6.pok.ibm.com
   ll6.pok.ibm.com.3.0!10/16/2009 09:19!01/16/2009 09:21! 
                       No_Group!ll5.pok.ibm.com

8. This example generates a WLM CPU and memory statistics listing where
   c704f5sq06.55.0 is a parallel job step currently running on two nodes
   c704f5sq05 and c704f5sq06. If consumable resource enforcement is
   enabled, the -w option can be used to obtain CPU and memory
   statistics of job steps in the running state.
   
   llrq -w c704f5sq06.55.0

   You should receive output similar to the following: 
     
   ===== c704f5sq06.ppd.pok.ibm.com.55.0@c704f5sq06.ppd.pok.ibm.com ====
         c704f5sq05.ppd.pok.ibm.com.55.0@c704f5sq06.ppd.pok.ibm.com:
                 Resource: CPU
                         snapshot: 13
                         total: 14996
                 Resource: Real Memory
                         snapshot: 0
                         high water: 718
                 Resource: Virtual Memory
                         snapshot: 98
                         high water: 25284
                 Resource: Large Page Memory
                         snapshot: 96
   
         c704f5sq06.ppd.pok.ibm.com.55.0@c704f5sq06.ppd.pok.ibm.com:
                 Resource: CPU
                         snapshot: 13
                         total: 14549
                 Resource: Real Memory
                         snapshot: 0
                         high water: 382
                 Resource: Virtual Memory
                         snapshot: 81
                         high water: 29109
                 Resource: Large Page Memory
                         snapshot: 80
    
   The standard listing includes the following fields:
    
   high water
            The highest number of memory pages used. Real Memory and
            Virtual Memory resources only.

   snapshot For CPU and Real Memory consumption, it is the current
            percentage of the total resources available. For Virtual
            Memory and Large Page Memory, it is the current usage in
            megabytes.
    
   The following statistics are displayed for every node the job is
   running on: 

   *  The current CPU resource consumption as a percentage of the total
      resources available
   *  The total CPU time consumed in milliseconds
   *  The current real memory consumption as a percentage of the total
      resources available
   *  The highest number of real memory pages used
   *  The current virtual memory usage in megabytes
   *  The highest number of virtual memory pages used
   *  The current large page memory usage in megabytes

9. The following is sample llrq -l output for task instances and
   allocated hosts if the job requested MCM affinity:
   
   Allocated Hosts: e189f4rp04.ppd.pok.ibm.com:: 
                       MCM0:CPU< 0-5 >;,MCM0:CPU< 0-5 >;  
                    + e189f4rp03.ppd.pok.ibm.com:: 
                       MCM1:CPU< 4-5 >;,MCM1:CPU< 4-5 >; 
   
   Num Task Inst: 4
         Task Instance: e189f4rp04:0:MCM0:CPU< 0-5 >; 
         Task Instance: e189f4rp04:1:MCM0:CPU< 0-5 >; 
         Task Instance: e189f4rp03:2:MCM1:CPU< 4-5 > 
         Task Instance: e189f4rp03:3:MCM1:CPU< 4-5 > 

   Note that the < > notation will be used to list individual CPU IDs
   instead of the CPU count ( ) notation when the RSET_SUPPORT
   configuration file keyword is set to RSET_MCM_AFFINITY.

10. The following example shows the Resource Set information in the llrq
    -l listing when the consumable CPUs Resource Set requirement is
    requested:
    
    Allocated Hosts : e189f4rp01.ppd.pok.ibm.com:: 
                         CPU< 0-5 >,CPU< 0-5>
                      + e189f4rp02.ppd.pok.ibm.com:: 
                         CPU< 0-5 >,CPU< 0-5 >
   
    Num Task Inst: 4
          Task Instance: e189f4rp01:0:CPU< 0-5 >
          Task Instance: e189f4rp01:1:CPU< 0-5 >
          Task Instance: e189f4rp02:2:CPU< 0-5 >
          Task Instance: e189f4rp02:3:CPU< 0-5 >

11. The following example shows output for the llrq -l command when SMT
    is requested:
    
    ===== Job Step blablahome.clusters.com.22.0@blablahome.clusters.com ====
       Job Step Id: blablahome.clusters.com.22.0@blablahome.clusters.com
          Job Name: blablahome.clusters.com.22
    .
    .
    .
            Status: Running
    .
    .
    .
        Large Page: N
        Coschedule: no
     SMT requested: yes
    Checkpointable: no
    .
    .
    .

12. This following example lists the network usages assigned to the job
    step in addition to other resources of the job: 

    llrq -l

    You should receive a response similar to the following: 
    
    ==== Job Step c890f1ec05.ppd.pok.ibm.com.18.0@blablahome.clusters.com ===
    Job Step Id: c890f1ec05.ppd.pok.ibm.com.18.0@blablahome.clusters.com
    ..................
    Network Usages: 0(1, LAPI, US, 1, 0 rCxt Blks),
                    18338657682652659715(1, MPI, US, 1, 0 rCxt Blks),
    ------------------------------------------------------------------------
   
    Node
    ----
   
    Name            :
    Requirements    :
    Preferences     :
    Node minimum    : 1
    Node maximum    : 1
    Node actual     : 1
    Allocated Hosts : c890f1ec06.ppd.pok.ibm.com:RUNNING:MCM1:CPU<0>, \
                      MCM1:CPU<1>
    Master Task
    -----------
   
    Executable   : /usr/bin/poe
    Exec Args    : /tmp/llbld/bin/btat -t 1 -d 90 -m 100 -v -ilevel 6 \ 
                   -labelio yes -pmdlog yes
    Num Task Inst: 1 
    Task Instance: c890f1ec06:-1
   
    Task
    ----
   
    Num Task Inst: 2
    Task Instance: c890f1ec06:0:MCM1:CPU< 0 >
    Task Instance: c890f1ec06:1:MCM1:CPU< 1 >
   
    Node
    ----
   
    Name           :
    Requirements   :
    Preferences    :
    Node minimum   : 1
    Node maximum   : 1
    Node actual    : 1
    Allocated Hosts: c890f1ec07.ppd.pok.ibm.com:RUNNING:MCM0:CPU< 0 >
   
    Task
    ----
   
    Num Task Inst: 1
    Task Instance: c890f1ec07:2:MCM0:CPU< 0 >
    ..................
   
    ------------------------------------------------------------------------
   
    Job Step Status on Allocated Hosts
    ----------------------------------
   
    c890f1ec06.ppd.pok.ibm.com:RUNNING
    c890f1ec07.ppd.pok.ibm.com:RUNNING
    c890f1ec08.ppd.pok.ibm.com:RUNNING
   
    1 job step(s) in query, 0 waiting, 0 pending, 1 running, 0 held,
    0 preempted

Security

LoadLeveler administrators and users can issue this command.
