llrstatus - Query machine information

Use the llrstatus command to return status information about machines in
the LoadLeveler cluster.


Syntax

 
llrstatus
         [-?] [-H] [-v] [-W] [-R] [-M] [-l] [-a] [-d]
         [-f category_list] [-r category_list] [-h hostlist | hostlist]


Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-R 
   Lists the machine consumable resources associated with each machine
   for which status is requested. This option should not be used with
   any other option.

-M 
   Lists the Multiple Chip Modules (MCMs) available on a machine, where:
   

   Available CPUs
            Are the CPU IDs of the CPUs available for LoadLeveler on
            this MCM.
   Adapters Are the switch adapters connected to this MCM of the form: 
            [available windows, available rCxtBlocks]
             
            where:
             
            available windows
                     Is the total number of windows on the adapter.
            available rCxt blocks
                     Is the total number of rCxt blocks on the adapter.
    

   Note that the < > notation will be used to list individual CPU IDs
   instead of the CPU count ( ) notation when the RSET_SUPPORT
   configuration file keyword is set to RSET_MCM_AFFINITY.

-l 
   Specifies that a long listing be generated for each machine for which
   status is requested. If -l is not specified, the standard list is
   generated.

-a 
   Displays information for each virtual adapter followed by information
   for each physical adapter it manages. This flag also displays the
   port number on each InfiniBand adapter port.

-d 
   Displays a list of regions and its corresponding active region
   manager.

-f category_list
   Is a blank-delimited list of categories you want to query. Each
   specified category must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag is used to
   create a customized version of the standard llrstatus listing. The
   output fields produced by this flag all have a fixed length. The
   output is displayed in the order in which the categories are
   specified. category_list can be one or more of the following: 

   %a       Hardware architecture

   %act     Number of job steps dispatched by the resource manager
            daemon on this machine

   %cpu     Number of CPUs on this machine

   %d       Available disk space in the LoadLeveler execute directory

   %i       Number of seconds since last keyboard or mouse activity

   %inq     Number of job steps in the job queue of this job manager
            machine

   %l       Berkeley one-minute load average

   %m       Physical memory on this machine

   %n       Machine name

   %o       Operating system on this machine

   %sca     Availability of the job manager daemon

   %scs     State of the job manager daemon

   %sta     Availability of the startd daemon

   %sts     State of the startd daemon

   %v       Available swap space (free paging space) of this machine

-r category_list
   Is a blank-delimited list of categories to query. Each specified
   category must be preceded by a percent sign. The category_list cannot
   contain duplicate entries. This flag is used to create a customized
   version of the standard llrstatus listing. The output produced by
   this flag is considered raw, in that the fields can be variable in
   length. Output fields are separated by an exclamation point (!).
   category_list can be one or more of the categories listed under the
   -f flag.

-h hostlist

hostlist
   Is a blank-delimited list of machines for which status is requested.


Description

If you have more than a few machines configured for LoadLeveler,
consider redirecting the output to a file when using the -l  flag. Each
machine periodically updates the resource manager with a snapshot of its
situation on an interval calculated by POLLING_FREQUENCY *
POLLS_PER_UPDATE. Since the information returned by using llrstatus is a
collection of such snapshots, all taken at varying times, the total
picture may not be completely consistent.

Certain resources such as remote direct-memory access (RDMA) have their
available value always calculated by startd. Available ConsumableCpus
resources are calculated by startd if the value is specified as all in
the administration file. When the value of a resource is calculated by
startd, the llrstatus command appends a plus (+) sign to the resource
name in the output reports. Resources that are automatically created,
such as RDMA, have a less than (<) sign appended to them.



Examples

1. This example generates the standard listing where there are two nodes
   in the cluster. The standard listing is generated when you do not
   specify the -l option with the llrstatus command. 
   llrstatus 
    
   You should receive output similar to the following:
    

   Name                    Schedd InQ Act Startd Run LdAvg Idle Arch  OpSys
   k10n09.ppd.pok.ibm.com  Avail   3   1  Run      1 2.72     0 R6000 AIX53
   k10n12.ppd.pok.ibm.com  Avail   0   0  Idle     0 0.00   365 R6000 AIX53
   
   R6000/AIX53            2 machines   3 jobs   1 running tasks
   Total Machines         2 machines   3 jobs   1 running tasks
    
   The Resource Manager is defined on k10n09.ppd.pok.ibm.com
   
   All machines on the machine_list are present. 
    

   The standard listing includes the following fields:
    

   Idle     The number of seconds since keyboard or mouse activity in a
            login session was detected. Highest number displayed is
            9999.

   InQ      Number of job steps in the manager's job queue of this
            Schedd machine.

   LdAvg    Berkeley one-minute load average on this machine.

   Name     Host name of the machine.

   OpSys    The operating system on this machine.

   Run      The number of initiators used by the startd daemon to run
            LoadLeveler jobs on this machine. One initiator is used for
            each serial job step and one initiator is used for each task
            of a parallel job step.

   Schedd   State of the job manager daemon (LoadL_schedd), which can be
            one of the following: 
            *  Down
            *  Drned (Drained)
            *  Drning (Draining)
            *  Avail (Available)


   Startd   State of the startd daemon, which can be: 
            *  Busy
            *  Down
            *  Idle
            *  None
            *  Run (Running)
            *  Suspnd (Suspend)


   Total Machines
            The standard listing includes the following summary fields: 

            jobs     The number of job steps in LoadLeveler job queues.

            machines The number of machines in the cluster that have
                     made a status report to the resource manager.

            running tasks
                     The number of initiators used by all the startd
                     daemons in the LoadLeveler cluster. One initiator
                     is used for each serial job step. One initiator is
                     used for each task of a parallel job step.
    

   The standard listing also contains summary information for the
   cluster such as the type of scheduler and the cluster name.

2. This example generates the long listing. The long listing is
   generated when you specify the -l flag with the llrstatus command.
   See Appendix C, "llrstatus -l command output listing" for sample
   output of long listings. 
   llrstatus -l c271f2rp02
    

   The long listing includes the following fields:

   
   Adapter  Network adapter information associated with this machine. 
            *  For a switch adapter, the information format is: 
               adapter_name(network_type, interface_name, interface_address,
               multilink_address, switch_node_number or adapter_logical_id,
               total_adapter_windows, total rCxt blocks, 
               adapter_fabric_connectivity)              

               For example:                

               Adapter = network1833865768265265971s(striped,ml0,10.0.0.53,,-1,0,
                  0 rCxt Blks,0111,) 
               network18338657682652659713(aggregate ,,,10.0.0.53,-1,0,
                  0 rCxt Blks,0,) 
               network18338657682652659714(aggregate,,,10.0.0.53,-1,64,
                  0 rCxt Blks,1,) 
               network18338657682652659715(aggregate,,,10.0.0.53,-1,64,
                  0 rCxt Blks,1,) 
               network18338657682652659716(aggregate,,,10.0.0.53,-1,64,
                  0 rCxt Blks,1,) 
                

               Possible values for adapter_state are:                

               AdapterHBInterval
                        Specifies the amount of time, in seconds, that
                        defines the heartbeat interval between the
                        region manager and startd.

               AdapterHBRetries
                        Specifies the number of heartbeat intervals that
                        the region manager will wait before declaring
                        the adapter on startd as down.

               ErrAdapter 
                        The adapter information is incorrect. More
                        information might be available in the network
                        table API log.

               ErrDown  The adapter has been reported as down. This
                        field is displayed as part of the command output
                        when the adapter is found to be down by either
                        an adapter heartbeat, or by the input/output
                        control (ioctl) or protocol network services
                        daemon (PNSD) status on the machine.

               ErrInternal
                        An error occurred while accessing the adapter.
                        More information might be available in the
                        network table API log and if the D_FULLDEBUG and
                        D_ADAPTER flags are specified for STARTD_DEBUG.

               ErrNotConfigured
                        The adapter is not configured. This field is
                        displayed as part of the command output only
                        during start up and reconfiguration as a default
                        value until it is changed by either an ioctl or
                        PNSD, or an adapter heartbeat.

               ErrNTBL  An error occurred while accessing the network
                        table API. More information might be available
                        if the D_FULLDEBUG and D_ADAPTER flags are
                        specified for  STARTD_DEBUG.

               ErrPerm  The network table API reported that LoadLeveler
                        does not have permission to access the adapter.
                        More information might be available in the
                        network table API log.

               ErrPNSD  An error occurred in the network table API. More
                        information might be available in the network
                        table API log.

               ErrType  The network table API reported that the adapter
                        is not a switch adapter. Check the adapter
                        configuration.

               HB_DOWN  Heartbeat is down between the startd and region
                        manager.

               HB_REGION_DOWN
                        The region manager is down.

               HB_UNKNOWN
                        The initial heartbeat state.

               HB_UP    Heartbeat is up between the startd and region
                        manager.

               MachineDown
                        The machine to which the adapter is attached
                        could not be reached by LoadLeveler to query
                        status.

               NOT READY
                        An unspecified problem occurred when accessing
                        the adapter state. More information might be
                        available if the D_FULLDEBUG and D_ADAPTER flags
                        are specified for  STARTD_DEBUG.

               READY    The adapter can be used for communication.

            *  For non-switch adapters, the format is: 
               adapter_name(network_type, interface_name, interface_address,
               interface_netmask, multilink_address, config_state, heartbeat_state, 
               adapter_state)                

               For example:                

               en0(ethernet,c890f4ec05.ppd.pok.ibm.com,9.114.80.53,,READY,HB_UP,
                  READY) 
               ml0(multilink,10.0.0.53,10.0.0.53,,READY,HB_UP,READY)
                

               Arch     Hardware architecture of this machine.

               Completed
                        The job manager has this number of completed
                        jobs.

               Config Time Stamp
                        Date and time of last configuration or
                        reconfiguration.

               ConfiguredClasses
                        List of configured classes and the associated
                        number of configured initiators on this machine.

               ConsumableResources
                        List of consumable resources associated with
                        this machine. Each element of this list has the
                        format: resource_name(available, total). 

                        Note: The individual CPU ID < > notation will be
                        used to list individual CPU IDs instead of the
                        CPU count ( ) notation for machines where the
                        RSET_SUPPORT configuration file keyword is set
                        to RSET_MCM_AFFINITY. The CPU count ( ) notation
                        will be used when the RSET_SUPPORT configuration
                        file keyword is set to RSET_USER_DEFINED or
                        RSET_NONE, or if this keyword is not specified
                        in the configuration file.


               CONTINUE The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        suspended jobs are continued on this machine.

               Cpus     Number of CPUs on this machine.

               
               Disk     Available space, in kilobytes (less 512 KB) in
                        LoadLeveler's execute directory on this machine.

               Entered Current State
                        Date and time when machine state was set.

               FabricConnectivity
                        Represents the current state of connectivity
                        between the machine and the switch through
                        switch adapters. The format of the field is:
                        network_id: connectivity, network_id:
                        connectivity... where connectivity is either 1
                        or 0. A value of 1 indicates an active
                        connection from the machine to a given
                        network_id through one of the switch adapters. 

                        If a machine does not have switch adapters, the
                        FabricConnectivity field has no meaning and
                        should be ignored by the user.


               Feature  Set of all features on this machine.

               FreeLargePageMemory
                        Free Large Page memory. 

                        In LoadLeveler for Linux, the
                        FreeLargePageMemory field has no meaning and
                        should be ignored by the user.


               FreeRealMemory
                        Free real memory, in megabytes, on this machine.
                        This value should track closely with the "fre"
                        value of the vmstat command and the "free" value
                        of the svmon -G command whose units are 4 KB
                        blocks.

               Held     The job manager has this number of held jobs.

               Idle     The job manager has this number of idle jobs.

               Keyboard Idle
                        Number of seconds since last keyboard or mouse
                        activity.

               KILL     The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        jobs running on this machine should be sent the
                        SIGKILL signal.

               LargePageMemory
                        Configured Large Page physical memory. 

                        In LoadLeveler for Linux, the LargePageMemory
                        field has no meaning and should be ignored by
                        the user.


               LargePageSize
                        The size of a Large Page memory block. 

                        In LoadLeveler for Linux, the LargePageSize
                        field has no meaning and should be ignored by
                        the user.


               LoadAvg  Berkely one-minute load average on machine.

               Machine  Fully qualified name of the machine.

               Machine Mode
                        The type of job this machine can run. This can
                        be: batch, interactive, or general.

               MasterMachPriority
                        The machine priority for the parallel master
                        node.

               Mcms     The MCMs information associated with this
                        machine has the format: 
                        mcm_info ... mcm_info
                         

                        The format of mcm_info is:
                         

                        MCMnumber Available Cpus: < cpulist > (Total Cpus)  
                        Adapters: adapater_info .... adapter_info                          

                        where:                         

                        Available Cpus
                           Are the CPUs available for LoadLeveler on
                           this MCM.

                        Adapters Are the switch adapters connected to
                           this MCM. 

                           where:                            

                           number   Is the MCM sequence number:

                           cpulist   Is a blank-delimited list of
                           individual CPU IDs or CPU ranges, or a
                           combination of both CPU IDs and CPU ranges
                           associated with the MCM.

                           adapter_info
                           Has the format:
                           [available windows, available memory]                            

                           where:                            

                           available windows
                           Is the total number of available windows.

                           available memory
                           Is the total available memory. It is the
                           number of rCxt blocks for switch adapters.

               Memory   Regular physical memory, in megabytes, on this
                        machine.

               Name     Host name of the machine.

               OpSys    Operating system on this machine.

               PagesFreed
                        Pages freed per second. This value corresponds
                        to the "fr" value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesFreed field
                        has no meaning and should be ignored by the
                        user.

               PagesPaged In
                        Pages paged in from paging space per second.
                        This value corresponds to the "pi" value of the
                        vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedIn field
                        has no meaning and should be ignored by the
                        user.

               PagesPagedOut
                        Pages paged out to paging space per second. This
                        value corresponds to the "po" value of the
                        vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedOut
                        field has no meaning and should be ignored by
                        the user.

               PagesScanned
                        Pages scanned by the page-replacement algorithm
                        per second. This value corresponds to the "sr"
                        value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesScanned field
                        has no meaning and should be ignored by the
                        user.

               Pending  The job manager has this number of pending jobs.

               Pool     The identifier of the pool where this startd
                        machine is located.

               Region   Specifies the name of the region to which this
                        machine belongs.

               Remove Pending
                        The job manager has this number of pending jobs
                        to be removed.

               RSetSupportType
                        Indicates the type of RSet support set up on a
                        machine. Possible values are: 

                        RSET_MCM_AFFINITY
                           Creates and attaches RSets for tasks to
                           satisfy memory and affinity requests.
                        RSET_NONE
                           Indicates that LoadLeveler RSet support is
                           not available.
                        RSET_USER_DEFINED
                           Attaches user-created RSets to Tasks.

               Running steps
                        The list of job steps currently running on this
                        machine.

               ScheddAvail
                        Flag indicating if machine is running a job
                        manager daemon (LoadL_schedd), (0=no, 1=yes).

               ScheddRunning
                        The number of job steps submitted to this
                        machine that are running somewhere in the
                        LoadLeveler cluster.

               ScheddState
                        The state of the Schedd daemon on this machine,
                        which can be one of the following: 
                        *  Down
                        *  Drned (Drained)
                        *  Drning (Draining)
                        *  Avail (Available)


               Speed    Speed associated with the machine.

               SMT      Indicates whether the simultaneous
                        multithreading (SMT) function is turned on, off,
                        or is not supported in the running machine.
                        Valid values are Enabled, Disabled, or Not
                        Supported.

               START    The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        jobs can be started on this machine.

               StartdAvail
                        Flag indicating if machine is running a startd
                        daemon (0=no, 1=yes).

               Starting The job manager has this number of jobs
                        starting.

               State    State of the startd daemon, which can be: 
                        *  Busy
                        *  Down
                        *  Idle
                        *  None
                        *  Running
                        *  Suspend                         

                        For more information, see the description of the
                        startd daemon in TWS LoadLeveler: Resource 
                        Manager.

               Subnet   The TCP/IP subnet that this machine resides on.

               SUSPEND  The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        running jobs should be suspended on this
                        machine.

               TimeStamp
                        The date and time the resource manager last
                        received a status update from the job manager on
                        this machine.

               Tmp      Available space, in kilobytes (less than 512 KB)
                        in the /tmp directory on this machine.

               Total Jobs
                        The number of total job steps submitted to the
                        job manager on this machine.

               TotalMemory
                        The sum of configured regular and Large Page
                        memory.

               Unexpanded
                        The job manager has this number of unexpanded
                        jobs.

               VACATE   The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        suspended jobs are vacated on this machine.

               Virtual Memory
                        Available swap space (free paging space) in
                        kilobytes, on this machine.

3. This example generates a listing of all of the consumable resources
   associated with all of the machines in the LoadLeveler cluster. 
   llrstatus -R    

   You should receive output similar to the following:    

   Machine                       Consumable Resource(Total)
   -------------------------     ------------------------------------------
   c209f1n01.ppd.pok.ibm.com     ConsumableCpus(4)+ ConsumableMemory
                                   (1.000 gb) n01_res(500)
   c209f1n02.ppd.pok.ibm.com     ConsumableCpus< 0 1 2 3 4 >n02_res(500) 
                                   Frame5(10)
   c209f1n05.ppd.pok.ibm.com     ConsumableCpus(4)+ ConsumableMemory
                                  (1.000 gb) spice2g6(360)
   
   Resources with "+" appended to their names have the Total value reported 
   from Startd.    

   Note:  The individual CPU ID < > notation will be used to list
   individual CPU IDs instead of the CPU count ( ) notation for machines
   where the RSET_SUPPORT configuration file keyword is set to
   RSET_MCM_AFFINITY. The CPU count ( ) notation will be used when the
   RSET_SUPPORT configuration file keyword is set to RSET_USER_DEFINED
   or RSET_NONE, or if this keyword is not specified in the
   configuration file.

4. This example generates a listing of information related to MCMs of
   machines in the LoadLeveler cluster. 
      
   llrstatus -M    

   You should receive output similar to the following:
    

   Machine               MCM details 
   --------------------- -------------------------------------------------
   c890f1ec12.ppd.pok.ibm.com
         MCM0
            Available Cpus :< 0-15 >(16)
            Adapters       :network18338657682652659713[64,0 rCxt Blks]DOWN
                            network18338657682652659714[64,0 rCxt Blks]
         MCM1
            Available Cpus :< 16-31 >(16)
            Adapters       :network18338657682652659715[64,0 rCxt Blks]
                            network18338657682652659716[64,0 rCxt Blks]
         MCM2
            Available Cpus :< 32-47 >(16)
            Adapters       :network18338657682652659713[64,0 rCxt Blks]
                            network18338657682652659714[64,0 rCxt Blks]
         MCM3
            Available Cpus :< 48-63 >(16)
            Adapters       :network18338657682652659715[64,0 rCxt Blks]
                            network18338657682652659716[64,0 rCxt Blks]
    

   Note: The -M option will list the MCM information only when the
   RSET_SUPPORT configuration file keyword is set to RSET_MCM_AFFINITY.

5. This example generates a customized and formatted standard listing. 
      
   llrstatus -f %n %scs %inq %m %v %sts %l %o    

   You should receive output similar to the following:    

   Name             Schedd  InQ  Memory  FreeVMemory Startd LdAvg  OpSys
   ll5.pok.ibm.com  Avail   0    128     22708       Run    0.23   AIX53
   ll6.pok.ibm.com  Avail   3    224     16732       Run    0.51   AIX53
   
   R6000/AIX53             2 machines      3  jobs      3  running tasks
   Total Machines          2 machines      3  jobs      3  running tasks
   
   The Resource Manager is defined on 115.pok.ibm.com
   
   All machines on the machine_list are present.

6. This example generates a customized and unformatted (raw) standard
   listing. 

   Customized, Unformatted Standard Listing: A customized Output fields
   are separated by an exclamation point (!).    

   llrstatus -r %n %scs %inq %m %v %sts %l %o    

   You should receive output similar to the following:    

   ll5.pok.ibm.com!Avail!0!128!22688!Running!0.14!AIX53
   ll6.pok.ibm.com!Avail!3!224!16668!Running!0.37!AIX53

7. This example generates a listing containing information about the
   status of adapters associated with all of the machines in the
   LoadLeveler cluster: 

   llrstatus -a    

   You should receive output similar to the following:    

   ========================================================================
   c890f4ec05.ppd.pok.ibm.com
   iba0(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,01,)
   iba1(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,11,)
   network1833865768265265971s(striped,ml0,10.0.0.53,,-1,0,0 rCxt Blks,
      0111,)
   network18338657682652659713(aggregate,,,10.0.0.53,-1,0,0 rCxt Blks,0,)
   ib0(InfiniBand,192.168.8.53,192.168.8.53,10.0.0.53,158486581,64,
      0 rCxt Blks,0,,ErrDown,HB_UP,ErrDown,1,MCM0)
   network18338657682652659714(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
   ib1(InfiniBand,192.168.9.53,192.168.9.53,10.0.0.53,158486581,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
   network18338657682652659715(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
   ib2(InfiniBand,192.168.10.53,192.168.10.53,10.0.0.53,158486581,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
   network18338657682652659716(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
   ib3(InfiniBand,192.168.11.53,192.168.11.53,10.0.0.53,158486581,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
   en0(ethernet,c890f4ec05.ppd.pok.ibm.com,9.114.80.53,,READY,HB_UP,READY)
   ml0(multilink,10.0.0.53,10.0.0.53,,READY,HB_UP,READY)
   
   ========================================================================
   c890f4ec04.ppd.pok.ibm.com
   iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
   iba1(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
   network1833865768265265971s(striped,ml0,10.0.0.52,,-1,64,0 rCxt Blks,
      1111,)
   network18338657682652659713(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib0(InfiniBand,192.168.8.52,192.168.8.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM0)
   network18338657682652659714(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib1(InfiniBand,192.168.9.52,192.168.9.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
   network18338657682652659715(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib2(InfiniBand,192.168.10.52,192.168.10.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
   network18338657682652659716(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib3(InfiniBand,192.168.11.52,192.168.11.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
   en0(ethernet,c890f4ec04.ppd.pok.ibm.com,9.114.80.52,,READY,HB_UP,READY)
   ml0(multilink,10.0.0.52,10.0.0.52,,READY,HB_UP,READY)

    
   *  For a switch adapter, the information format is: 
      adapter_name(network_type, interface_name, interface_address,
      multilink_address, switch_node_number or adapter_logical_id,
      total_adapter_windows, total rCxt blocks,
      adapter_fabric_connectivity)       

      For example:       

      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,10.0.0.52,,-1,64,
         0 rCxt Blks,1111,)
      network18338657682652659713(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)       

      Note that InfiniBand adapters contain additional information. The
      format is:       

      adapter_name(network_type, interface_name, interface_address,
      multilink_address, switch_node_number or adapter_logical_id,
      total_adapter_windows, total rCxt blocks, adapter_fabric_connectivity,
      config_state, heartbeat_state, adapter_state, port_number, MCM_id)       

      For example:       

      ib0(InfiniBand,192.168.8.52,192.168.8.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM0)

   *  For non-switch adapters, the format is: 
      adapter_name(network_type, interface_name, interface_address, 
      multilink_address, config_state, heartbeat_state, adapter_state)       

      For example: 

      en0(ethernet,c197blade8b09.ppd.pok.ibm.com,9.114.198.233,,
      READY,HB_UP, READY)

   *  For InfiniBand, this example displays the port number on each
      InfiniBand adapter. The llrstatus command does not show port
      information for adapters that are not InfiniBand adapters:  

      llrstatus -a       

      You should receive output similar to the following:       

      ========================================================================
      c890f4ec05.ppd.pok.ibm.com
      iba0(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,01,)
      iba1(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,10.0.0.53,,-1,0,
         0 rCxt Blks,0111,)
      network18338657682652659713(aggregate,,,10.0.0.53,-1,0,0 rCxt Blks,0,)
      ib0(InfiniBand,192.168.8.53,192.168.8.53,10.0.0.53,158486581,64,
         0 rCxt Blks,0,,ErrDown,HB_UP,ErrDown,1,MCM0)
      network18338657682652659714(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
      ib1(InfiniBand,192.168.9.53,192.168.9.53,10.0.0.53,158486581,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
      network18338657682652659715(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
      ib2(InfiniBand,192.168.10.53,192.168.10.53,10.0.0.53,158486581,64, 
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
      network18338657682652659716(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
      ib3(InfiniBand,192.168.11.53,192.168.11.53,10.0.0.53,158486581,64, 
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
      en0(ethernet,c890f4ec05.ppd.pok.ibm.com,9.114.80.53,,READY,HB_UP,READY)
      ml0(multilink,10.0.0.53,10.0.0.53,,READY,HB_UP,READY)
      
      ========================================================================
      c890f4ec04.ppd.pok.ibm.com
      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      iba1(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,10.0.0.52,,-1,64,
         0 rCxt Blks,1111,)
      network18338657682652659713(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib0(InfiniBand,192.168.8.52,192.168.8.52,10.0.0.52,158486580,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM0)
      network18338657682652659714(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib1(InfiniBand,192.168.9.52,192.168.9.52,10.0.0.52,158486580,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
      network18338657682652659715(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib2(InfiniBand,192.168.10.52,192.168.10.52,10.0.0.52,158486580,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
      network18338657682652659716(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib3(InfiniBand,192.168.11.52,192.168.11.52,10.0.0.52,158486580,64, 
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
      en0(ethernet,c890f4ec04.ppd.pok.ibm.com,9.114.80.52,,READY,HB_UP,READY)
      ml0(multilink,10.0.0.52,10.0.0.52,,READY,HB_UP,READY)

8. The following example shows output for the llrstatus -l command that
   displays the SMT state for the machine: 
   ========================================================================
        Name = devf1n01.clusters.com
     Machine = devf1n01.clusters.com
        Arch = ppc64
       OpSys = Linux2
   .
   .
   .
     Feature = SMT
   .
   .
   .
         SMT = Enabled | Disabled | Not Supported
   TimeStamp = Fri 23 Jan 2009 04:44:06 PM CST
   .
   .
   .  

9. On a system that has one InfiniBand adapter and multiple MCMs, the
   llrstatus -a or llrstatus -M command displays the InfiniBand network
   interfaces connected to only one MCM. Processors in the other MCMs,
   however, can still communicate through the same network interfaces. 
   *  For example, if you issue: 

      llrstatus -a c395f2n02       

      You should receive output similar to the following:       

      ========================================================================
      c395f3n07.ppd.pok.ibm.com
      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,192.168.200.22,,-1,64,
         0 rCxt Blks,11,)
      network18338657682652659713(aggregate,,,192.168.200.22,-1,64,
         0 rCxt Blks,1,)
      ib0(InfiniBand,c395f3n07ib0,192.168.100.22,192.168.200.22,158473815,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
      network18338657682652659714(aggregate,,,192.168.200.22,-1,64,
         0 rCxt Blks,1,)
      ib1(InfiniBand,c395f3n07ib1,192.168.101.22,192.168.200.22,158473815,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
      en0(ethernet,c395f3n07.ppd.pok.ibm.com,9.114.30.87,,READY,HB_UP,READY)
      ml0(multilink,c395f3n07ml0,192.168.200.22,,READY,HB_UP,READY)

   *  For example, if you issue: 

      llrstatus -M c395f2n02       

      You should receive output similar to the following:
       

      Machine               MCM details
      --------------------- --------------------------------------------------
      c395f2n02.ppd.pok.ibm.com
            MCM0
               Available Cpus :< 0-3 >(4)
               Adapters       :
            MCM1
               Available Cpus :< 4-7 >(4)
               Adapters       :network18338657682652659713[64,0 rCxt Blks]
                               network18338657682652659714[64,0 rCxt Blks]
            MCM2
               Available Cpus :< 8-11 >(4)
               Adapters       :
            MCM3
               Available Cpus :< 12-15 >(4)
               Adapters       :
             

Security

LoadLeveler administrators and users can issue this command.