/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBMs sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <pthread.h>
#include <stdio.h>
#include "Thread.h"
#include "Mutex.h"
#include <stdint.h>
#include "llrapi.h"
#include "rm_symbols.h"
#include "Scheduler.h"
#include "Log.h"
#include "Adapter.h"

Adapter*
Adapter::getManagedAdapter(const char* adapter_name) {
	Adapter* adapter = NULL;
	for (int i=0; adapter == NULL && i<managed_adapters.size(); i++) {
		if (strcmp(adapter_name, managed_adapters[i]->Name) == 0) {
			adapter = managed_adapters[i];
		}
	}

	if (adapter == NULL) {
		adapter = new Adapter(adapter_name, true);
		adapter->get_ref();
		managed_adapters.push_back(adapter);
	}

	return adapter;
}

void
Adapter::clear_managed_adapters() {
	for (int i=0; i<managed_adapters.size(); i++) {
		managed_adapters[i]->rel_ref();
	}

	managed_adapters.clear();
}

bool
Adapter::updateData(void* llr_adapter, llr_event_type_t event_type) {
	Scheduler&     s   = Scheduler::getInstance();
	llr_element_t* err = NULL;
	int            rc  = 0;

	// always update the state
	GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterConfigStatus, ConfigStatus, err);
	GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterConnectionStatus, ConnectionStatus, err);
	GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterHeartbeatStatus, HeartbeatStatus, err);

	// update adapter information, but not in case of LLR_MACHINE_UPDATE_ADAPTER_EVENT
	if (event_type != LLR_MACHINE_UPDATE_ADAPTER_EVENT) {
		GET_DATA_P(rc, s.rm_handle, llr_adapter, LLR_AdapterInterfaceAddress, InterfaceAddress, err);
		GET_DATA_P(rc, s.rm_handle, llr_adapter, LLR_AdapterInterfaceNetmask, InterfaceNetmask, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterMinWindowSize64, MinWindowSize64, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterMaxWindowSize64, MaxWindowSize64, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterMemory64, Memory64, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterTotalWindowCount, TotalWindowCount, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterMCMId, MCMId, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterPortNumber, PortNumber, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterLmc, Lmc, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterNetworkId, NetworkId, err);
		GET_DATA  (rc, s.rm_handle, llr_adapter, LLR_AdapterNetworkType, NetworkType, err);
	}

	if (_managed == false) {
		llr_data_list_t llr_managed_adapter_list;
		void* llr_managed_adapter = NULL;
		GET_DATA(rc, s.rm_handle, llr_adapter, LLR_AdapterGetManagedAdapterList, llr_managed_adapter_list, err);
		GET_DATA(rc, s.rm_handle, &llr_managed_adapter_list, LLR_AdapterGetFirstManagedAdapter, llr_managed_adapter, err);
		while (llr_managed_adapter != NULL) {
			err = NULL;
			char* managed_adapter_name = NULL;
			GET_DATA_P(rc, s.rm_handle, llr_managed_adapter, LLR_AdapterName, managed_adapter_name, err);
			if (!err) {
				Adapter* managed_adapter = getManagedAdapter(managed_adapter_name);
				managed_adapter->updateData(llr_managed_adapter, event_type);
			}

			FREE_IF_SET(managed_adapter_name);

			GET_DATA(rc, s.rm_handle, &llr_managed_adapter_list, LLR_AdapterGetNextManagedAdapter, llr_managed_adapter, err);
		}
	}

	display_adapter_data();

	return (rc == 0);
}

void
Adapter::display_adapter_data() {
	log(1, "ADAPTER Name:                    %s\n", Name);
	log(1, "ADAPTER NetworkType:             %s\n", enum_to_string((llr_network_type_t)NetworkType));
	log(1, "ADAPTER Managed:                 %s\n", _managed ? "YES" : "NO");
	log(2, "ADAPTER InterfaceAddress:        %s\n", InterfaceAddress);
	log(2, "ADAPTER InterfaceNetmask:        %s\n", InterfaceNetmask);
	log(2, "ADAPTER MinWindowSize64:         %llu\n", MinWindowSize64);
	log(2, "ADAPTER MaxWindowSize64:         %llu\n", MaxWindowSize64);
	log(2, "ADAPTER Memory64:                %llu\n", Memory64);
	log(2, "ADAPTER TotalWindowCount:        %d\n", TotalWindowCount);
	log(2, "ADAPTER MCMId:                   %d\n", MCMId);
	log(2, "ADAPTER PortNumber:              %d\n", PortNumber);
	log(2, "ADAPTER Lmc:                     %d\n", Lmc);
	log(2, "ADAPTER NetworkId:               %llu\n", NetworkId);
	log(2, "ADAPTER ConfigStatus:            %s\n", enum_to_string((llr_adapter_state_t)ConfigStatus));
	log(2, "ADAPTER ConnectionStatus:        %s\n", enum_to_string((llr_adapter_state_t)ConnectionStatus));
	log(2, "ADAPTER HeartbeatStatus:         %s\n", enum_to_string((llr_heartbeat_status_t)HeartbeatStatus));
}

Adapter::Adapter(const char* adapter_name, bool managed) {
	Name                        = strdup(adapter_name);
	InterfaceAddress            = NULL;
	InterfaceNetmask            = NULL;
	MinWindowSize64             = 0;
	MaxWindowSize64             = 0;
	Memory64                    = 0;
	TotalWindowCount            = 0;
	MCMId                       = 0;
	PortNumber                  = 0;
	Lmc                         = 0;
	NetworkId                   = 0;
	NetworkType                 = 0;
	_managed                    = managed;
	_windows_in_use             = 0;
	_exclusive_use              = 0;
	ConfigStatus                = LLR_Unknown;
	ConnectionStatus            = LLR_Unknown;
	HeartbeatStatus             = LLR_HB_UNKNOWN;
}

Adapter::~Adapter() {
	clear_managed_adapters();

	FREE_IF_SET(Name);
	FREE_IF_SET(InterfaceAddress);
	FREE_IF_SET(InterfaceNetmask);
}
