/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <stdio.h>
#include <unistd.h>
#include "Mutex.h"
#include "Thread.h"
#include "Scheduler.h"
#include "SchedulingThread.h"
#include "EventListenerThread.h"
#include "rm_symbols.h"

void
EventListenerThread::run() {
	Scheduler&     scheduler = Scheduler::getInstance();
	llr_event_t*   event;
	llr_element_t* err_object = NULL;
	int            rc;

	log(1, "EVENT_LISTENER_THREAD: Started.\n");
	while (err_object == NULL && scheduler.RMisUP()) {
		err_object = NULL;

		// Wait for event
		log(2, "EVENT_LISTENER_THREAD: call llr_read_events. This is a blocking call.\n");
		rc = llr_read_events_p(scheduler.rm_handle, &err_object);
		log(2, "EVENT_LISTENER_THREAD: return from read_events: rc = %d \n", rc);
		if (err_object) {
			llr_error_p(&err_object, LLR_ERROR_PRINT_STDERR);
			break;
		}

		bool signal_scheduling_thread = false;
		do {
			// Pop event from event queue
			rc = llr_get_event_p(scheduler.rm_handle, &event, &err_object);
			log(2, "EVENT_LISTENER_THREAD: return from get_event: rc = %d, event is %sNULL\n",
			    rc, (event) ? "not " : "");
			if (err_object) {
				llr_error_p(&err_object, LLR_ERROR_PRINT_STDERR);
				break;
			}
			if (event) {
				log(1, "EVENT_LISTENER_THREAD: Queue %s to scheduling thread\n",
				    enum_to_string(event->event_type));
				scheduler.event_queue_lock.lock();
				scheduler.event_queue.push_back(event);
				scheduler.event_queue_lock.unlock();

				switch(event->event_type) {
				case LLR_RESOURCE_MGR_UP_EVENT:
				case LLR_ALL_MACHINES_EVENT:
				case LLR_ALL_JOBS_EVENT:
				case LLR_JOB_ADD_EVENT:
				case LLR_JOB_STEP_STATE_CHANGE_EVENT:
					signal_scheduling_thread = true;
					break;
				}

			}
		} while (event != NULL);

		if (signal_scheduling_thread) {
			log(1, "EVENT_LISTENER_THREAD: Signaling scheduling thread\n");
			scheduler.schedulingThread()->signal();
		}
	}

	if (err_object) {
		log(0, "EVENT_LISTENER_THREAD: Exited with an error. Will initiate RM Reset\n");
		scheduler.RMReset();
	} else {
		log(1, "EVENT_LISTENER_THREAD: Exited.\n");
	}
}
