/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <string.h>
#include <stdlib.h>
#include "Adapter.h"
#include "ClassRec.h"
#include "Resource.h"
#include "MCM.h"

#ifndef Machine_h
#define Machine_h

class Step;

class Machine : public Object {
public:
	Machine(char* machine_name);
	~Machine();

	bool updateData(void* machine, llr_event_type_t event_type);
	void display_machine_data(llr_event_type_t event_type);

	Adapter* getAdapter(const char* adapter_name);
	void clear_adapters();

	ClassRec* getClassRec(const char* class_name);
	void clear_class_recs();

	Resource* getResource(const char* resource_name);
	void clear_resources();

	MCM* getMCM(int mcm_id);
	void clear_mcms();

	int tasksAvailable(const Step* step);

	/** SCHEDULER RESOURCE BOOKKEEPING **/
	void tasksRunning(int tasks_running) {
		_tasks_running = tasks_running;
	}

	int tasksRunning() const {
		return _tasks_running;
	}

	void stepsRunning(int steps_running) {
		_steps_running = steps_running;
	}

	int stepsRunning() const {
		return _steps_running;
	}
	/************************************/

        /* Machine object data */
	char*   Architecture;       /* machine architecture                            */
	int     Disk;               /* avail space (KB) in execute dir                 */
	int64_t Disk64;             /* avail space (KB) in execute dir                 */
	char*   MachineName;        /* official hostname                               */
	time_t  TimeStamp;          /* time when machine data received                 */
	int     VirtualMemory;      /* available swap space in kilobytes               */
	int64_t VirtualMemory64;    /* available swap space in Kb                      */
	int     RealMemory;         /* physical memory                                 */
	int64_t RealMemory64;       /* physical memory                                 */
	double  Speed;              /* speed associated with machine                   */
	int     MaxTasks;           /* max number of tasks allowed                     */
	int     PrestartedStarters; /* Prestarted Starters to be started               */
	char*   MachineMode;        /* configured machine mode                         */
	int*    PoolList;           /* list of configured pools                        */
	int     PoolListSize;       /* number of configured pools                      */
	int     ScheddState;        /* schedd state                                    */
	char**  StepList;           /* stepids scheduled to run                        */
	char**  ConfiguredClassList;/* initiators defined                              */
	char**  FeatureList;        /* features defined                                */
	char*   OperatingSystem;    /* machine operating system                        */
	double  LoadAverage;        /* load average                                    */
	int     FreeRealMemory;     /* free real memory in Mbytes                      */
	int64_t FreeRealMemory64;   /* free real memory in Mbytes                      */
	int     PagesScanned;       /* pages scanned/sec by page replacement algorithm */
	int64_t PagesScanned64;     /* pages scanned/sec by page replacement algorithm */
	int     PagesFreed;         /* pages freed/sec by page replacement algorithm   */
	int64_t PagesFreed64;       /* pages freed/sec by page replacement algorithm   */
	int     PagesPagedIn;       /* pages paged in from paging space                */
	int64_t PagesPagedIn64;     /* pages paged in from paging space                */
	int     PagesPagedOut;      /* pages paged out to paging space                 */
	int64_t PagesPagedOut64;    /* pages paged out to paging space                 */
	int     CPUs;               /* number of cpus                                  */
	int*    CPUList;            /* list of cpus                                    */
	char*   StartdState;        /* startd state                                    */
	int     ScheddRunningJobs;  /* running jobs assigned schedd                    */
	int     ScheddTotalJobs;    /* total jobs assigned schedd                      */
	int     StartdRunningJobs;  /* running jobs assigned startd                    */
	int     KbddIdle;           /* seconds kbdd is idle                            */
	char*   StartExpr;          /* START expression                                */
	char*   SuspendExpr;        /* SUSPEND expression                              */
	char*   ContinueExpr;       /* CONTINUE expression                             */
	char*   VacateExpr;         /* VACATE expression                               */
	char*   KillExpr;           /* KILL expression                                 */
	int64_t LargePageSize64;    /* Size of Large Page memory block (bytes)         */
	int64_t LargePageCount64;   /* Total number of Large Page memory blocks        */
	int64_t LargePageFree64;    /* Number of Large Page memory blocks on freelist  */
	int     ConfigTimeStamp;    /* Time of last reconfig                           */
	int     RSetSupport;        /* The RSet Support configured                     */
	int     SMTState;           /* The SMT state of a node                         */

	Mutex   lock;

	std::vector<Adapter*>  adapters;
	std::vector<ClassRec*> class_recs;
	std::vector<Resource*> resources;
	std::vector<MCM*>      mcms;

	bool _reconciled;

private:
	int _tasks_running;
	int _steps_running;
};


#endif
