/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <pthread.h>
#include <sys/time.h>
#include <errno.h>
#include "Mutex.h"
#include "Log.h"


Mutex::Mutex() {
	pthread_mutex_init(&_mutex, NULL);
}

Mutex::~Mutex() {
	pthread_mutex_destroy(&_mutex);
}

void Mutex::lock() {
	pthread_mutex_lock(&_mutex);
}

void Mutex::unlock() {
	pthread_mutex_unlock(&_mutex);
}

Condition::Condition() {
	pthread_mutex_init(&_mutex, NULL);
	pthread_mutex_lock(&_mutex);
	pthread_cond_init(&_cond, NULL);
}

Condition::~Condition() {
	pthread_cond_destroy(&_cond);
	pthread_mutex_destroy(&_mutex);
}

void Condition::signal() {
	pthread_cond_signal(&_cond);
}

void Condition::wait() {
	pthread_cond_wait(&_cond, &_mutex);
}

bool Condition::timed_wait(unsigned long milisec) {
	struct timeval  tv;
	struct timespec ts;

	gettimeofday(&tv, NULL);

	ts.tv_sec  = (int)(milisec/1000);
	ts.tv_nsec = (milisec - ts.tv_sec*1000) * 1000000L;
	ts.tv_sec  += tv.tv_sec;
	ts.tv_nsec += tv.tv_usec * 1000;
	int rc = pthread_cond_timedwait(&_cond, &_mutex, &ts);
	return (rc == ETIMEDOUT);
}
