/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <pthread.h>
#include <stdio.h>
#include "Thread.h"
#include "Mutex.h"
#include "Step.h"
#include <stdint.h>
#include "llrapi.h"
#include "rm_symbols.h"
#include "Scheduler.h"
#include "Log.h"
#include "Node.h"
#include "AdapterReq.h"
#include "Machine.h"

int
Step::comparePriority(const Step& step) const {
        if (_job->SubmitTime < step._job->SubmitTime) {
                return -1;
        } else if (_job->SubmitTime > step._job->SubmitTime) {
                return +1;
        } else {
                return 0;
        }
}

void
Step::clear_nodes() {
	for (int i=0; i<nodes.size(); i++) {
		nodes[i]->rel_ref();
	}

	nodes.clear();
}

void
Step::clear_adapter_reqs() {
	for (int i=0; i<adapter_reqs.size(); i++) {
		adapter_reqs[i]->rel_ref();
	}

	adapter_reqs.clear();
}

void
Step::clear_machines() {
	for (int i=0; i<machines.size(); i++) {
		machines[i]->rel_ref();
	}

	machines.clear();
}

void
Step::addMachine(Machine* machine) {
	for (int i=0; i<machines.size(); i++) {
		if (machines[i] == machine) {
			return;
		}
	}

	machine->get_ref();
	machines.push_back(machine);
}

bool
Step::updateData(void* llr_step) {
	Scheduler&     s   = Scheduler::getInstance();
	llr_element_t* err = NULL;
	int            rc  = 0;

	GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepName, StepName, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepNodeCount, NodeCount, err);

	clear_nodes();
	llr_data_list_t llr_node_list;
	void* llr_node = NULL;
	GET_DATA(rc, s.rm_handle, llr_step, LLR_StepGetNodeList, llr_node_list, err);
	GET_DATA(rc, s.rm_handle, &llr_node_list, LLR_StepGetFirstNode, llr_node, err);
	for (int i=0; i<NodeCount; i++) {

		Node* node = new Node();
		nodes.push_back(node);
		node->get_ref();
		node->updateData(llr_node);
		GET_DATA(rc, s.rm_handle, &llr_node_list, LLR_StepGetNextNode, llr_node, err);
	}

	clear_adapter_reqs();
	llr_data_list_t llr_adapter_req_list;
	void* llr_adapter_req = NULL;
	GET_DATA(rc, s.rm_handle, llr_step, LLR_StepGetAdapterReqList, llr_adapter_req_list, err);
	GET_DATA(rc, s.rm_handle, &llr_adapter_req_list, LLR_StepGetFirstAdapterReq, llr_adapter_req, err);
	while (llr_adapter_req != NULL) {
		AdapterReq* adapter_req = new AdapterReq();
		adapter_reqs.push_back(adapter_req);
		adapter_req->get_ref();
		adapter_req->updateData(llr_adapter_req);
		GET_DATA(rc, s.rm_handle, &llr_adapter_req_list, LLR_StepGetNextAdapterReq, llr_adapter_req, err);
	}

	GET_DATA(rc, s.rm_handle, llr_step, LLR_StepMachineCount, MachineCount, err);

	llr_data_list_t llr_machine_list;
	void* llr_machine = NULL;
	GET_DATA(rc, s.rm_handle, llr_step, LLR_StepGetMachineList, llr_machine_list, err);
	GET_DATA(rc, s.rm_handle, &llr_machine_list, LLR_StepGetFirstMachine, llr_machine, err);
	while (llr_machine != NULL) {
		char* machine_name = NULL;
		GET_DATA_P(rc, s.rm_handle, llr_machine, LLR_MachineName, machine_name, err);
		Machine* machine = s.getMachine(machine_name);
		addMachine(machine);
		log(2, "STEP MACHINE: %s\n", machine_name);
		FREE_IF_SET(machine_name);
		GET_DATA(rc, s.rm_handle, &llr_machine_list, LLR_StepGetNextMachine, llr_machine, err);
	}

        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepMachUsageCount, MachUsageCount, err);
	llr_data_list_t llr_mach_usage_list;
	GET_DATA(rc, s.rm_handle, llr_step, LLR_StepGetMachUsageList, llr_mach_usage_list, err);
	void* llr_mach_usage = NULL;
	GET_DATA(rc, s.rm_handle, &llr_mach_usage_list, LLR_StepGetFirstMachUsage, llr_mach_usage, err);
	while (llr_mach_usage != NULL) {
		GET_DATA(rc, s.rm_handle, &llr_mach_usage_list, LLR_StepGetNextMachUsage, llr_mach_usage, err);
		// TODO: Load all data
	}

	//LLR_StepGetMasterTask;          /* LL_element * (Task): master task on step */
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepAccountNumber, AccountNumber, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepComment, Comment, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCompletionCode, CompletionCode, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCompletionDate, CompletionDate, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepEnvironment, Environment, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepErrorFile, ErrorFile, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepExecSize, ExecSize, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepImageSize, ImageSize, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepImageSize64, ImageSize64, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepInputFile, InputFile, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepIwd, Iwd, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepJobClass, JobClass, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepNodeUsage, NodeUsage, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepOutputFile, OutputFile, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepParallelMode, ParallelMode, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepShell, Shell, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStartCount, StartCount, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStartDate, StartDate, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStartTime, StartTime, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepDispatchTime, DispatchTime, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepTaskInstanceCount, TaskInstanceCount, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuLimitHard, CpuLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuLimitHard64, CpuLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuLimitSoft, CpuLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuLimitSoft64, CpuLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepDataLimitHard, DataLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepDataLimitHard64, DataLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepDataLimitSoft, DataLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepDataLimitSoft64, DataLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepAsLimitHard64, AsLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepAsLimitSoft64, AsLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepNprocLimitHard64, NprocLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepNprocLimitSoft64, NprocLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepMemlockLimitHard64, MemlockLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepMemlockLimitSoft64, MemlockLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepLocksLimitHard64, LocksLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepLocksLimitSoft64, LocksLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepNofileLimitHard64, NofileLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepNofileLimitSoft64, NofileLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCoreLimitSoft, CoreLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCoreLimitSoft64, CoreLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCoreLimitHard, CoreLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCoreLimitHard64, CoreLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepFileLimitHard, FileLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepFileLimitHard64, FileLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepFileLimitSoft, FileLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepFileLimitSoft64, FileLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepRssLimitHard, RssLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepRssLimitHard64, RssLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepRssLimitSoft, RssLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepRssLimitSoft64, RssLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStackLimitHard, StackLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStackLimitHard64, StackLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStackLimitSoft, StackLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStackLimitSoft64, StackLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuStepLimitHard, CpuStepLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuStepLimitHard64, CpuStepLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuStepLimitSoft, CpuStepLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpuStepLimitSoft64, CpuStepLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepWallClockLimitHard, WallClockLimitHard, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepWallClockLimitHard64, WallClockLimitHard64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepWallClockLimitSoft, WallClockLimitSoft, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepWallClockLimitSoft64, WallClockLimitSoft64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepState, State, err);
        GET_DATA_PP(rc, s.rm_handle, llr_step, LLR_StepHostList, HostList, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepLoadLevelerGroup, LoadLevelerGroup, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepTaskGeometry, TaskGeometry, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepTotalNodesRequested, TotalNodesRequested, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepRestart, Restart, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepTotalTasksRequested, TotalTasksRequested, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepTasksPerNodeRequested, TasksPerNodeRequested, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepBlocking, Blocking, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepUserTime64, StepUserTime64, err);

        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepSystemTime64, StepSystemTime64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepMaxrss64, StepMaxrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepIxrss64, StepIxrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepIdrss64, StepIdrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepIsrss64, StepIsrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepMinflt64, StepMinflt64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepMajflt64, StepMajflt64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepNswap64, StepNswap64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepInblock64, StepInblock64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepOublock64, StepOublock64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepMsgsnd64, StepMsgsnd64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepMsgrcv64, StepMsgrcv64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepNsignals64, StepNsignals64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepNvcsw64, StepNvcsw64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStepNivcsw64, StepNivcsw64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterUserTime64, StarterUserTime64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterSystemTime64, StarterSystemTime64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterMaxrss64, StarterMaxrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterIxrss64, StarterIxrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterIdrss64, StarterIdrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterIsrss64, StarterIsrss64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterMinflt64, StarterMinflt64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterMajflt64, StarterMajflt64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterNswap64, StarterNswap64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterInblock64, StarterInblock64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterOublock64, StarterOublock64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterMsgsnd64, StarterMsgsnd64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterMsgrcv64, StarterMsgrcv64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterNsignals64, StarterNsignals64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterNvcsw64, StarterNvcsw64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepStarterNivcsw64, StarterNivcsw64, err);

        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCheckpointable, Checkpointable, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCheckpointing, Checkpointing, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptAccumTime, CkptAccumTime, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptFailStartTime, CkptFailStartTime, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepCkptFile, CkptFile, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepCkptSubDir, CkptSubDir, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptGoodElapseTime, CkptGoodElapseTime, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptGoodStartTime, CkptGoodStartTime, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptTimeHardLimit, CkptTimeHardLimit, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptTimeHardLimit64, CkptTimeHardLimit64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptTimeSoftLimit, CkptTimeSoftLimit, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptTimeSoftLimit64, CkptTimeSoftLimit64, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptRestart, CkptRestart, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCkptRestartSameNodes, CkptRestartSameNodes, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepWallClockUsed, WallClockUsed, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepLargePage, LargePage, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepMaxProtocolInstances, MaxProtocolInstances, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepBulkXfer, BulkXfer, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepTotalRcxtBlocks, TotalRcxtBlocks, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepUserRcxtBlocks, UserRcxtBlocks, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepPreemptable, Preemptable, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepRsetName, RsetName, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepMcmAffinityOptions, McmAffinityOptions, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepTaskAffinity, TaskAffinity, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCpusPerCore, CpusPerCore, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepCkptExecuteDirectory, CkptExecuteDirectory, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepMasterVirtualIP, MasterVirtualIP, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepMasterRealIP, MasterRealIP, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepMasterNetmask, MasterNetmask, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepVipNetmask, VipNetmask, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepMetaClusterPoeHostname, MetaClusterPoeHostname, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepMetaClusterJobID, MetaClusterJobID, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepAcctKey, AcctKey, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepDependency, Dependency, err);
	/*
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepBgJobId, BgJobId, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepBgJobState, BgJobState, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepBgConnectionRequested, BgConnectionRequested, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepBgPartitionAllocated, BgPartitionAllocated, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepBgErrorText, BgErrorText, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepBgSizeRequested, BgSizeRequested, err);
        GET_DATA_P(rc, s.rm_handle, llr_step, LLR_StepBgShapeRequested, BgShapeRequested, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepBgPartitionType, BgPartitionType, err);
	*/
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepCoschedule, Coschedule, err);
        GET_DATA(rc, s.rm_handle, llr_step, LLR_StepSMTRequired, SMTRequired, err);

	display_step_data();
	return (rc == 0);
}

void
Step::display_step_data() {
	log(1, "STEP StepID:                     %s\n", StepID);
	log(2, "STEP StepName:                   %s\n", StepName);
	log(2, "STEP Parallel:                   %s\n", ParallelMode ? "YES" : "NO");
	log(2, "STEP State:                      %s\n", enum_to_string((llr_step_state_t)State));
	log(2, "STEP NodeCount:                  %d\n", NodeCount);
	log(2, "STEP MachineCount:               %d\n", MachineCount);
	log(2, "STEP Comment:                    %s\n", Comment);
	log(2, "STEP LoadLevelerGroup:           %s\n", LoadLevelerGroup);
	log(2, "STEP TaskGeometry:               %s\n", TaskGeometry);
	log(2, "STEP TotalNodesRequested:        %s\n", TotalNodesRequested);
	log(2, "STEP TotalTasksRequested:        %d\n", TotalTasksRequested);
	log(2, "STEP TasksPerNodeRequested:      %d\n", TasksPerNodeRequested);
	log(2, "STEP Blocking:                   %d\n", Blocking);
	for (int i=0; HostList && HostList[i]; i++) {
		log(2, "STEP HostList[%d]                %s\n", HostList[i]);
	}
}

Step::Step(const char* step_id) {
        StepName               = strdup(step_id);
	StepID                 = strdup(step_id);
        NodeCount              = 0;
        MachineCount           = 0;
        MachUsageCount         = 0;
        AccountNumber          = NULL;
        Comment                = NULL;
        CompletionCode         = 0;
        CompletionDate         = 0;
        Environment            = NULL;
        ErrorFile              = NULL;
        ExecSize               = 0;
        ImageSize              = 0;
        ImageSize64            = 0;
        InputFile              = NULL;
        Iwd                    = NULL;
        JobClass               = NULL;
        NodeUsage              = 0;
        OutputFile             = NULL;
        ParallelMode           = 0;
        Shell                  = NULL;
        StartCount             = 0;
        StartDate              = 0;
        StartTime              = 0;
        DispatchTime           = 0;
        TaskInstanceCount      = 0;
        CpuLimitHard           = 0;
        CpuLimitHard64         = 0;
        CpuLimitSoft           = 0;
        CpuLimitSoft64         = 0;
        DataLimitHard          = 0;
        DataLimitHard64        = 0;
        DataLimitSoft          = 0;
        DataLimitSoft64        = 0;
        AsLimitHard64          = 0;
        AsLimitSoft64          = 0;
        NprocLimitHard64       = 0;
        NprocLimitSoft64       = 0;
        MemlockLimitHard64     = 0;
        MemlockLimitSoft64     = 0;
        LocksLimitHard64       = 0;
        LocksLimitSoft64       = 0;
        NofileLimitHard64      = 0;
        NofileLimitSoft64      = 0;
        CoreLimitSoft          = 0;
        CoreLimitSoft64        = 0;
        CoreLimitHard          = 0;
        CoreLimitHard64        = 0;
        FileLimitHard          = 0;
        FileLimitHard64        = 0;
        FileLimitSoft          = 0;
        FileLimitSoft64        = 0;
        RssLimitHard           = 0;
        RssLimitHard64         = 0;
        RssLimitSoft           = 0;
        RssLimitSoft64         = 0;
        StackLimitHard         = 0;
        StackLimitHard64       = 0;
        StackLimitSoft         = 0;
        StackLimitSoft64       = 0;
        CpuStepLimitHard       = 0;
        CpuStepLimitHard64     = 0;
        CpuStepLimitSoft       = 0;
        CpuStepLimitSoft64     = 0;
        WallClockLimitHard     = 0;
        WallClockLimitHard64   = 0;
        WallClockLimitSoft     = 0;
        WallClockLimitSoft64   = 0;
        State                  = 0;
        HostList               = NULL;
        LoadLevelerGroup       = NULL;
        TaskGeometry           = NULL;
        TotalNodesRequested    = NULL;
        Restart                = 0;
        TotalTasksRequested    = 0;
        TasksPerNodeRequested  = 0;
        Blocking               = 0;
        StepUserTime64         = 0;
        StepSystemTime64       = 0;
        StepMaxrss64           = 0;
        StepIxrss64            = 0;
        StepIdrss64            = 0;
        StepIsrss64            = 0;
        StepMinflt64           = 0;
        StepMajflt64           = 0;
        StepNswap64            = 0;
        StepInblock64          = 0;
        StepOublock64          = 0;
        StepMsgsnd64           = 0;
        StepMsgrcv64           = 0;
        StepNsignals64         = 0;
        StepNvcsw64            = 0;
        StepNivcsw64           = 0;
        StarterUserTime64      = 0;
        StarterSystemTime64    = 0;
        StarterMaxrss64        = 0;
        StarterIxrss64         = 0;
        StarterIdrss64         = 0;
        StarterIsrss64         = 0;
        StarterMinflt64        = 0;
        StarterMajflt64        = 0;
        StarterNswap64         = 0;
        StarterInblock64       = 0;
        StarterOublock64       = 0;
        StarterMsgsnd64        = 0;
        StarterMsgrcv64        = 0;
        StarterNsignals64      = 0;
        StarterNvcsw64         = 0;
        StarterNivcsw64        = 0;
        Checkpointable         = 0;
        Checkpointing          = 0;
        CkptAccumTime          = 0;
        CkptFailStartTime      = 0;
        CkptFile               = NULL;
        CkptSubDir             = NULL;
        CkptGoodElapseTime     = 0;
        CkptGoodStartTime      = 0;
        CkptTimeHardLimit      = 0;
        CkptTimeHardLimit64    = 0;
        CkptTimeSoftLimit      = 0;
        CkptTimeSoftLimit64    = 0;
        CkptRestart            = 0;
        CkptRestartSameNodes   = 0;
        WallClockUsed          = 0;
        LargePage              = NULL;
        MaxProtocolInstances   = 0;
        BulkXfer               = 0;
        TotalRcxtBlocks        = 0;
        UserRcxtBlocks         = 0;
        Preemptable            = 0;
        RsetName               = NULL;
        McmAffinityOptions     = NULL;
        TaskAffinity           = 0;
        CpusPerCore            = 0;
        CkptExecuteDirectory   = NULL;
        MasterVirtualIP        = NULL;
        MasterRealIP           = NULL;
        MasterNetmask          = NULL;
        VipNetmask             = NULL;
        MetaClusterPoeHostname = NULL;
        MetaClusterJobID       = 0;
        AcctKey                = 0;
        Dependency             = NULL;
        BgJobId                = NULL;
        BgJobState             = 0;
        BgConnectionRequested  = 0;
        BgPartitionAllocated   = NULL;
        BgErrorText            = NULL;
        BgSizeRequested        = 0;
        BgShapeRequested       = NULL;
        BgPartitionType        = 0;
        Coschedule             = 0;
        SMTRequired            = 0;

	_job                   = NULL;

	_consumes_resources    = false;
}

Step::~Step() {
	clear_nodes();
	clear_adapter_reqs();
	clear_machines();

	_job = NULL;

	FREE_IF_SET(StepID);
	FREE_IF_SET(StepName);
	FREE_IF_SET(AccountNumber);
	FREE_IF_SET(Comment);
	FREE_IF_SET(Environment);
	FREE_IF_SET(ErrorFile);
	FREE_IF_SET(InputFile);
	FREE_IF_SET(Iwd);
	FREE_IF_SET(JobClass);
	FREE_IF_SET(OutputFile);
	FREE_IF_SET(Shell);
	FREE_IF_SET_ARR(HostList);
	FREE_IF_SET(LoadLevelerGroup);
	FREE_IF_SET(TaskGeometry);
	FREE_IF_SET(TotalNodesRequested);
	FREE_IF_SET(CkptFile);
	FREE_IF_SET(CkptSubDir);
	FREE_IF_SET(LargePage);
	FREE_IF_SET(RsetName);
	FREE_IF_SET(McmAffinityOptions);
	FREE_IF_SET(CkptExecuteDirectory);
	FREE_IF_SET(MasterVirtualIP);
	FREE_IF_SET(MasterRealIP);
	FREE_IF_SET(MasterNetmask);
	FREE_IF_SET(VipNetmask);
	FREE_IF_SET(MetaClusterPoeHostname);
	FREE_IF_SET(Dependency);
	FREE_IF_SET(BgJobId);
	FREE_IF_SET(BgPartitionAllocated);
	FREE_IF_SET(BgErrorText);
	FREE_IF_SET(BgShapeRequested);
}
