/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <pthread.h>
#include "Thread.h"
#include "Mutex.h"
#include "stdio.h"

int Thread::_next_id = 1;
Mutex Thread::_next_id_mutex;

pthread_key_t Thread::_thread_specific_key;
bool Thread::_thread_specific_key_initialized = false;
Mutex Thread::_thread_specific_key_mutex;

Thread::Thread() {
	Thread::_next_id_mutex.lock();
	_local_id = Thread::_next_id;
	++Thread::_next_id;
	Thread::_next_id_mutex.unlock();
}

Thread::~Thread() {
}



void
Thread::startThread() {
	get_ref();
	pthread_attr_init(&_attr);
	//pthread_attr_setdetachstate(&_attr, PTHREAD_CREATE_UNDETACHED);
	pthread_create(&_id, &_attr, &startup, this);
}

void*
Thread::startup(void* t) {
	Thread* thread = (Thread*)t;

	Thread::_thread_specific_key_mutex.lock();
	if (!Thread::_thread_specific_key_initialized) {
		int rc = pthread_key_create(&Thread::_thread_specific_key, NULL);
		Thread::_thread_specific_key_initialized = true;
	}
	Thread::_thread_specific_key_mutex.unlock();

	int rc = pthread_setspecific(Thread::_thread_specific_key, thread);

	thread->initialize();
	thread->run();
	thread->rel_ref();

	return NULL;
}

void
Thread::join() {
	pthread_join(_id, NULL);
}

