/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/signal.h>
#include <stdint.h> // for uint64_t
#include "llrapi.h"

main(int argc, char *argv[]) {

	llr_resmgr_handle_t *rm_handle;
	llr_element_t *err_object;
	char *job_id;
	int rc;
	int signal;

	if (argc != 2) {
		fprintf(stderr, "Usage: sample_cancel <job id>\n");
		exit(-1);
	}

	job_id = argv[1];

	err_object = NULL;
	rc = llr_init_resmgr(LLR_API_VERSION, &rm_handle, &err_object);
	if (rc != LLR_API_OK) {
		fprintf(stderr, "Resource manager API can not be intialized.\n");
		if (err_object) {
			llr_error(&err_object, LLR_ERROR_PRINT_STDERR);
		}
		exit(-1);
	}

	signal = SIGTERM;
	rc = llr_control_job(rm_handle, job_id, LLR_CANCEL_OP, &signal, &err_object); 
	if (rc != LLR_API_OK) {
		if (err_object) {
			llr_error(&err_object, LLR_ERROR_PRINT_STDERR);
		}
	}

	llr_free_resmgr(&rm_handle, &err_object);
}

