/* IBM_COPYRIGHT_BEGIN_TAG */
/*
 * Copyright IBM Corporation 2009. All rights reserved. The information contained
 * in these materials is provided for informational purposes only, and is provided AS IS
 * without warranty of any kind, express or implied. IBM shall not be responsible for any
 * damages arising out of the use of, or otherwise related to, these materials. Nothing
 * contained in these materials is intended to, nor shall have the effect of, creating any
 * warranties or representations from IBM or its suppliers or licensors, or altering the terms
 * and conditions of the applicable license agreement governing the use of IBM software.
 * References in these materials to IBM products, programs, or services do not imply that
 * they will be available in all countries in which IBM operates. Product release dates
 * and/or capabilities referenced in these materials may change at any time at IBM<92>s sole
 * discretion based on market opportunities or other factors, and are not intended to be a
 * commitment to future product or feature availability in any way. IBM, the IBM logo, AIX,
 * the AIX logo, and other IBM products and services are trademarks of the International
 * Business Machines Corporation, in the United States, other countries or both. Other
 * company, product, or service names may be trademarks or service marks of others.
 */
/* IBM_COPYRIGHT_END_TAG */

#include <stdint.h>
#include "llrapi.h"

#ifndef rm_symbols_h
#define rm_symbols_h

#define LLR_INIT_RESMGR           "llr_init_resmgr"
#define LLR_FREE_RESMGR           "llr_free_resmgr"
#define LLR_REGISTER_FOR_EVENTS   "llr_register_for_events"
#define LLR_UNREGISTER_FOR_EVENTS "llr_unregister_for_events"
#define LLR_READ_EVENTS           "llr_read_events"
#define LLR_GET_EVENT             "llr_get_event"
#define LLR_GET_EVENT_FD          "llr_get_event_fd"
#define LLR_FREE_EVENT            "llr_free_event"
#define LLR_GET_DATA              "llr_get_data"
#define LLR_START_JOB_STEP        "llr_start_job_step"
#define LLR_DELETE_JOB            "llr_delete_job"
#define LLR_ERROR                 "llr_error"

typedef int   (*llr_init_resmgr_t)          (int, llr_resmgr_handle_t **, llr_element_t **);
typedef int   (*llr_free_resmgr_t)          (llr_resmgr_handle_t **, llr_element_t **);
typedef int   (*llr_register_for_events_t)  (llr_resmgr_handle_t *, llr_event_registration_t *, llr_element_t **);
typedef int   (*llr_unregister_for_events_t)(llr_resmgr_handle_t *, llr_event_registration_t *, llr_element_t **);
typedef int   (*llr_read_events_t)          (llr_resmgr_handle_t *, llr_element_t **);
typedef int   (*llr_get_event_t)            (llr_resmgr_handle_t *, llr_event_t **event_data, llr_element_t **);
typedef int   (*llr_get_event_fd_t)         (llr_resmgr_handle_t *);
typedef int   (*llr_free_event_t)           (llr_resmgr_handle_t *, llr_event_t **, llr_element_t **);
typedef int   (*llr_get_data_t)             (llr_resmgr_handle_t *, llr_element_t *, llr_data_specification_t, void*, llr_element_t **);
typedef int   (*llr_start_job_step_t)       (llr_resmgr_handle_t *, const char *, llr_job_step_resource_t *, llr_job_step_opts_t *, llr_element_t **);
typedef int   (*llr_delete_job_t)           (llr_resmgr_handle_t *, const char *, llr_element_t **);
typedef char* (*llr_error_t)                (llr_element_t **, llr_error_opt_t);

extern llr_init_resmgr_t           llr_init_resmgr_p;
extern llr_free_resmgr_t           llr_free_resmgr_p;
extern llr_register_for_events_t   llr_register_for_events_p;
extern llr_unregister_for_events_t llr_unregister_for_events_p;
extern llr_read_events_t           llr_read_events_p;
extern llr_get_event_t             llr_get_event_p;
extern llr_get_event_fd_t          llr_get_event_fd_p;
extern llr_free_event_t            llr_free_event_p;
extern llr_get_data_t              llr_get_data_p;
extern llr_start_job_step_t        llr_start_job_step_p;
extern llr_delete_job_t            llr_delete_job_p;
extern llr_error_t                 llr_error_p;

#define FREE_IF_SET(v)     { if ((v) != NULL) free((v)); (v) = NULL; }
#define FREE_IF_SET_ARR(v) { for (int i=0; (v)&&(v)[i]; i++) free((v)[i]); if ((v) != NULL) free((v)); (v) = NULL; }

#define GET_DATA(rc, handle, elem, spec, var, err) {\
        if ((rc) != 0) {\
                (err) = NULL;\
        } else {\
                (rc) = llr_get_data_p((handle), (elem), (spec), &(var), &(err));\
                if ((rc) != 0) {\
                        log(0, "ERROR in llr_get_data for spec %d, rc=%d\n", (spec), (rc));\
                }\
        }\
}\

#define GET_DATA_P(rc, handle, elem, spec, var, err) {\
        FREE_IF_SET(var);\
        GET_DATA(rc, handle, elem, spec, var, err);\
}\

#define GET_DATA_PP(rc, handle, elem, spec, var, err) {\
        FREE_IF_SET_ARR(var);\
        GET_DATA(rc, handle, elem, spec, var, err);\
}\

const char* enum_to_string(llr_step_state_t s);
const char* enum_to_string(llr_event_type_t s);
const char* enum_to_string(llr_network_type_t s);
const char* enum_to_string(llr_network_mode_t s);
const char* enum_to_string(llr_adapter_state_t s);
const char* enum_to_string(llr_heartbeat_status_t s);

#endif
